//CMYK to Pantone v.2
//JS code  by John Wundes 
// johnwun@aol.com
// www.wundes.com
//////////////////////////////////////////////////////////////////
//
//		this script compares the color values of a selected CMYK object to 
//		the imbedded list of PMS coated colors, and returns the closest match(es)
//
//		Matching is based on cumulative (C+M+Y+K) values, so the PMS color with the
//		least total color divergence is always chosen. 
//		If colors are equally divergent, multiple matches will be displayed.
//
//		If no object is selected, or if the wrong type of object is selected,
//		user is prompted to manually enter CMYK values.
//		
//		as of V.2 RGB colors are also accepted.
//
//////////////////////////////////////////////////////////////////

// Array of Pantone Colors and CMYK equivilants

names = ["PANTONE 100 C","PANTONE 101 C","PANTONE 102 C","PANTONE 103 C","PANTONE 104 C","PANTONE 105 C","PANTONE 106 C","PANTONE 107 C","PANTONE 108 C","PANTONE 109 C","PANTONE 110 C","PANTONE 111 C","PANTONE 112 C","PANTONE 113 C","PANTONE 114 C","PANTONE 115 C","PANTONE 116 C","PANTONE 117 C","PANTONE 118 C","PANTONE 119 C","PANTONE 120 C","PANTONE 1205 C","PANTONE 121 C","PANTONE 1215 C","PANTONE 122 C","PANTONE 1225 C","PANTONE 123 C","PANTONE 1235 C","PANTONE 124 C","PANTONE 1245 C","PANTONE 125 C","PANTONE 1255 C","PANTONE 126 C","PANTONE 1265 C","PANTONE 127 C","PANTONE 128 C","PANTONE 129 C","PANTONE 130 C","PANTONE 131 C","PANTONE 132 C","PANTONE 133 C","PANTONE 134 C","PANTONE 1345 C","PANTONE 135 C","PANTONE 1355 C","PANTONE 136 C","PANTONE 1365 C","PANTONE 137 C","PANTONE 1375 C","PANTONE 138 C","PANTONE 1385 C","PANTONE 139 C","PANTONE 1395 C","PANTONE 140 C","PANTONE 1405 C","PANTONE 141 C","PANTONE 142 C","PANTONE 143 C","PANTONE 144 C","PANTONE 145 C","PANTONE 146 C","PANTONE 147 C","PANTONE 148 C","PANTONE 1485 C","PANTONE 149 C","PANTONE 1495 C","PANTONE 150 C","PANTONE 1505 C","PANTONE 151 C","PANTONE 152 C","PANTONE 1525 C","PANTONE 153 C","PANTONE 1535 C","PANTONE 154 C","PANTONE 1545 C","PANTONE 155 C","PANTONE 1555 C","PANTONE 156 C","PANTONE 1565 C","PANTONE 157 C","PANTONE 1575 C","PANTONE 158 C","PANTONE 1585 C","PANTONE 159 C","PANTONE 1595 C","PANTONE 160 C","PANTONE 1605 C","PANTONE 161 C","PANTONE 1615 C","PANTONE 162 C","PANTONE 1625 C","PANTONE 163 C","PANTONE 1635 C","PANTONE 164 C","PANTONE 1645 C","PANTONE 165 C","PANTONE 1655 C","PANTONE 166 C","PANTONE 1665 C","PANTONE 167 C","PANTONE 1675 C","PANTONE 168 C","PANTONE 1685 C","PANTONE 169 C","PANTONE 170 C","PANTONE 171 C","PANTONE 172 C","PANTONE 173 C","PANTONE 174 C","PANTONE 175 C","PANTONE 176 C","PANTONE 1765 C","PANTONE 1767 C","PANTONE 177 C","PANTONE 1775 C","PANTONE 1777 C","PANTONE 178 C","PANTONE 1785 C","PANTONE 1787 C","PANTONE 1788 C","PANTONE 179 C","PANTONE 1795 C","PANTONE 1797 C","PANTONE 180 C","PANTONE 1805 C","PANTONE 1807 C","PANTONE 181 C","PANTONE 1815 C","PANTONE 1817 C","PANTONE 182 C","PANTONE 183 C","PANTONE 184 C","PANTONE 185 C","PANTONE 186 C","PANTONE 187 C","PANTONE 188 C","PANTONE 189 C","PANTONE 1895 C","PANTONE 190 C","PANTONE 1905 C","PANTONE 191 C","PANTONE 1915 C","PANTONE 192 C","PANTONE 1925 C","PANTONE 193 C","PANTONE 1935 C","PANTONE 194 C","PANTONE 1945 C","PANTONE 195 C","PANTONE 1955 C","PANTONE 196 C","PANTONE 197 C","PANTONE 198 C","PANTONE 199 C","PANTONE 200 C","PANTONE 201 C","PANTONE 202 C","PANTONE 203 C","PANTONE 204 C","PANTONE 205 C","PANTONE 206 C","PANTONE 207 C","PANTONE 208 C","PANTONE 209 C","PANTONE 210 C","PANTONE 211 C","PANTONE 212 C","PANTONE 213 C","PANTONE 214 C","PANTONE 215 C","PANTONE 216 C","PANTONE 217 C","PANTONE 218 C","PANTONE 219 C","PANTONE 220 C","PANTONE 221 C","PANTONE 222 C","PANTONE 223 C","PANTONE 224 C","PANTONE 225 C","PANTONE 226 C","PANTONE 227 C","PANTONE 228 C","PANTONE 229 C","PANTONE 230 C","PANTONE 231 C","PANTONE 232 C","PANTONE 233 C","PANTONE 234 C","PANTONE 235 C","PANTONE 236 C","PANTONE 2365 C","PANTONE 237 C","PANTONE 2375 C","PANTONE 238 C","PANTONE 2385 C","PANTONE 239 C","PANTONE 2395 C","PANTONE 240 C","PANTONE 2405 C","PANTONE 241 C","PANTONE 2415 C","PANTONE 242 C","PANTONE 2425 C","PANTONE 243 C","PANTONE 244 C","PANTONE 245 C","PANTONE 246 C","PANTONE 247 C","PANTONE 248 C","PANTONE 249 C","PANTONE 250 C","PANTONE 251 C","PANTONE 252 C","PANTONE 253 C","PANTONE 254 C","PANTONE 255 C","PANTONE 256 C","PANTONE 2562 C","PANTONE 2563 C","PANTONE 2567 C","PANTONE 257 C","PANTONE 2572 C","PANTONE 2573 C","PANTONE 2577 C","PANTONE 258 C","PANTONE 2582 C","PANTONE 2583 C","PANTONE 2587 C","PANTONE 259 C","PANTONE 2592 C","PANTONE 2593 C","PANTONE 2597 C","PANTONE 260 C","PANTONE 2602 C","PANTONE 2603 C","PANTONE 2607 C","PANTONE 261 C","PANTONE 2612 C","PANTONE 2613 C","PANTONE 2617 C","PANTONE 262 C","PANTONE 2622 C","PANTONE 2623 C","PANTONE 2627 C","PANTONE 263 C","PANTONE 2635 C","PANTONE 264 C","PANTONE 2645 C","PANTONE 265 C","PANTONE 2655 C","PANTONE 266 C","PANTONE 2665 C","PANTONE 267 C","PANTONE 268 C","PANTONE 2685 C","PANTONE 269 C","PANTONE 2695 C","PANTONE 270 C","PANTONE 2705 C","PANTONE 2706 C","PANTONE 2707 C","PANTONE 2708 C","PANTONE 271 C","PANTONE 2715 C","PANTONE 2716 C","PANTONE 2717 C","PANTONE 2718 C","PANTONE 272 C","PANTONE 2725 C","PANTONE 2726 C","PANTONE 2727 C","PANTONE 2728 C","PANTONE 273 C","PANTONE 2735 C","PANTONE 2736 C","PANTONE 2738 C","PANTONE 274 C","PANTONE 2745 C","PANTONE 2746 C","PANTONE 2747 C","PANTONE 2748 C","PANTONE 275 C","PANTONE 2755 C","PANTONE 2756 C","PANTONE 2757 C","PANTONE 2758 C","PANTONE 276 C","PANTONE 2765 C","PANTONE 2766 C","PANTONE 2767 C","PANTONE 2768 C","PANTONE 277 C","PANTONE 278 C","PANTONE 279 C","PANTONE 280 C","PANTONE 281 C","PANTONE 282 C","PANTONE 283 C","PANTONE 284 C","PANTONE 285 C","PANTONE 286 C","PANTONE 287 C","PANTONE 288 C","PANTONE 289 C","PANTONE 290 C","PANTONE 2905 C","PANTONE 291 C","PANTONE 2915 C","PANTONE 292 C","PANTONE 2925 C","PANTONE 293 C","PANTONE 2935 C","PANTONE 294 C","PANTONE 2945 C","PANTONE 295 C","PANTONE 2955 C","PANTONE 296 C","PANTONE 2965 C","PANTONE 297 C","PANTONE 2975 C","PANTONE 298 C","PANTONE 2985 C","PANTONE 299 C","PANTONE 2995 C","PANTONE 300 C","PANTONE 3005 C","PANTONE 301 C","PANTONE 3015 C","PANTONE 302 C","PANTONE 3025 C","PANTONE 303 C","PANTONE 3035 C","PANTONE 304 C","PANTONE 305 C","PANTONE 306 C","PANTONE 307 C","PANTONE 308 C","PANTONE 309 C","PANTONE 310 C","PANTONE 3105 C","PANTONE 311 C","PANTONE 3115 C","PANTONE 312 C","PANTONE 3125 C","PANTONE 313 C","PANTONE 3135 C","PANTONE 314 C","PANTONE 3145 C","PANTONE 315 C","PANTONE 3155 C","PANTONE 316 C","PANTONE 3165 C","PANTONE 317 C","PANTONE 318 C","PANTONE 319 C","PANTONE 320 C","PANTONE 321 C","PANTONE 322 C","PANTONE 323 C","PANTONE 324 C","PANTONE 3242 C","PANTONE 3245 C","PANTONE 3248 C","PANTONE 325 C","PANTONE 3252 C","PANTONE 3255 C","PANTONE 3258 C","PANTONE 326 C","PANTONE 3262 C","PANTONE 3265 C","PANTONE 3268 C","PANTONE 327 C","PANTONE 3272 C","PANTONE 3275 C","PANTONE 3278 C","PANTONE 328 C","PANTONE 3282 C","PANTONE 3285 C","PANTONE 3288 C","PANTONE 329 C","PANTONE 3292 C","PANTONE 3295 C","PANTONE 3298 C","PANTONE 330 C","PANTONE 3302 C","PANTONE 3305 C","PANTONE 3308 C","PANTONE 331 C","PANTONE 332 C","PANTONE 333 C","PANTONE 334 C","PANTONE 335 C","PANTONE 336 C","PANTONE 337 C","PANTONE 3375 C","PANTONE 338 C","PANTONE 3385 C","PANTONE 339 C","PANTONE 3395 C","PANTONE 340 C","PANTONE 3405 C","PANTONE 341 C","PANTONE 3415 C","PANTONE 342 C","PANTONE 3425 C","PANTONE 343 C","PANTONE 3435 C","PANTONE 344 C","PANTONE 345 C","PANTONE 346 C","PANTONE 347 C","PANTONE 348 C","PANTONE 349 C","PANTONE 350 C","PANTONE 351 C","PANTONE 352 C","PANTONE 353 C","PANTONE 354 C","PANTONE 355 C","PANTONE 356 C","PANTONE 357 C","PANTONE 358 C","PANTONE 359 C","PANTONE 360 C","PANTONE 361 C","PANTONE 362 C","PANTONE 363 C","PANTONE 364 C","PANTONE 365 C","PANTONE 366 C","PANTONE 367 C","PANTONE 368 C","PANTONE 369 C","PANTONE 370 C","PANTONE 371 C","PANTONE 372 C","PANTONE 373 C","PANTONE 374 C","PANTONE 375 C","PANTONE 376 C","PANTONE 377 C","PANTONE 378 C","PANTONE 379 C","PANTONE 380 C","PANTONE 381 C","PANTONE 382 C","PANTONE 383 C","PANTONE 384 C","PANTONE 385 C","PANTONE 386 C","PANTONE 387 C","PANTONE 388 C","PANTONE 389 C","PANTONE 390 C","PANTONE 391 C","PANTONE 392 C","PANTONE 393 C","PANTONE 3935 C","PANTONE 394 C","PANTONE 3945 C","PANTONE 395 C","PANTONE 3955 C","PANTONE 396 C","PANTONE 3965 C","PANTONE 397 C","PANTONE 3975 C","PANTONE 398 C","PANTONE 3985 C","PANTONE 399 C","PANTONE 3995 C","PANTONE 400 C","PANTONE 401 C","PANTONE 402 C","PANTONE 403 C","PANTONE 404 C","PANTONE 405 C","PANTONE 406 C","PANTONE 407 C","PANTONE 408 C","PANTONE 409 C","PANTONE 410 C","PANTONE 411 C","PANTONE 412 C","PANTONE 413 C","PANTONE 414 C","PANTONE 415 C","PANTONE 416 C","PANTONE 417 C","PANTONE 418 C","PANTONE 419 C","PANTONE 420 C","PANTONE 421 C","PANTONE 422 C","PANTONE 423 C","PANTONE 424 C","PANTONE 425 C","PANTONE 426 C","PANTONE 427 C","PANTONE 428 C","PANTONE 429 C","PANTONE 430 C","PANTONE 431 C","PANTONE 432 C","PANTONE 433 C","PANTONE 434 C","PANTONE 435 C","PANTONE 436 C","PANTONE 437 C","PANTONE 438 C","PANTONE 439 C","PANTONE 440 C","PANTONE 441 C","PANTONE 442 C","PANTONE 443 C","PANTONE 444 C","PANTONE 445 C","PANTONE 446 C","PANTONE 447 C","PANTONE 448 C","PANTONE 4485 C","PANTONE 449 C","PANTONE 4495 C","PANTONE 450 C","PANTONE 4505 C","PANTONE 451 C","PANTONE 4515 C","PANTONE 452 C","PANTONE 4525 C","PANTONE 453 C","PANTONE 4535 C","PANTONE 454 C","PANTONE 4545 C","PANTONE 455 C","PANTONE 456 C","PANTONE 457 C","PANTONE 458 C","PANTONE 459 C","PANTONE 460 C","PANTONE 461 C","PANTONE 462 C","PANTONE 4625 C","PANTONE 463 C","PANTONE 4635 C","PANTONE 464 C","PANTONE 4645 C","PANTONE 465 C","PANTONE 4655 C","PANTONE 466 C","PANTONE 4665 C","PANTONE 467 C","PANTONE 4675 C","PANTONE 468 C","PANTONE 4685 C","PANTONE 469 C","PANTONE 4695 C","PANTONE 470 C","PANTONE 4705 C","PANTONE 471 C","PANTONE 4715 C","PANTONE 472 C","PANTONE 4725 C","PANTONE 473 C","PANTONE 4735 C","PANTONE 474 C","PANTONE 4745 C","PANTONE 475 C","PANTONE 4755 C","PANTONE 476 C","PANTONE 477 C","PANTONE 478 C","PANTONE 479 C","PANTONE 480 C","PANTONE 481 C","PANTONE 482 C","PANTONE 483 C","PANTONE 484 C","PANTONE 485 C","PANTONE 486 C","PANTONE 487 C","PANTONE 488 C","PANTONE 489 C","PANTONE 490 C","PANTONE 491 C","PANTONE 492 C","PANTONE 493 C","PANTONE 494 C","PANTONE 495 C","PANTONE 496 C","PANTONE 497 C","PANTONE 4975 C","PANTONE 498 C","PANTONE 4985 C","PANTONE 499 C","PANTONE 4995 C","PANTONE 500 C","PANTONE 5005 C","PANTONE 501 C","PANTONE 5015 C","PANTONE 502 C","PANTONE 5025 C","PANTONE 503 C","PANTONE 5035 C","PANTONE 504 C","PANTONE 505 C","PANTONE 506 C","PANTONE 507 C","PANTONE 508 C","PANTONE 509 C","PANTONE 510 C","PANTONE 511 C","PANTONE 5115 C","PANTONE 512 C","PANTONE 5125 C","PANTONE 513 C","PANTONE 5135 C","PANTONE 514 C","PANTONE 5145 C","PANTONE 515 C","PANTONE 5155 C","PANTONE 516 C","PANTONE 5165 C","PANTONE 517 C","PANTONE 5175 C","PANTONE 518 C","PANTONE 5185 C","PANTONE 519 C","PANTONE 5195 C","PANTONE 520 C","PANTONE 5205 C","PANTONE 521 C","PANTONE 5215 C","PANTONE 522 C","PANTONE 5225 C","PANTONE 523 C","PANTONE 5235 C","PANTONE 524 C","PANTONE 5245 C","PANTONE 525 C","PANTONE 5255 C","PANTONE 526 C","PANTONE 5265 C","PANTONE 527 C","PANTONE 5275 C","PANTONE 528 C","PANTONE 5285 C","PANTONE 529 C","PANTONE 5295 C","PANTONE 530 C","PANTONE 5305 C","PANTONE 531 C","PANTONE 5315 C","PANTONE 532 C","PANTONE 533 C","PANTONE 534 C","PANTONE 535 C","PANTONE 536 C","PANTONE 537 C","PANTONE 538 C","PANTONE 539 C","PANTONE 5395 C","PANTONE 540 C","PANTONE 5405 C","PANTONE 541 C","PANTONE 5415 C","PANTONE 542 C","PANTONE 5425 C","PANTONE 543 C","PANTONE 5435 C","PANTONE 544 C","PANTONE 5445 C","PANTONE 545 C","PANTONE 5455 C","PANTONE 546 C","PANTONE 5463 C","PANTONE 5467 C","PANTONE 547 C","PANTONE 5473 C","PANTONE 5477 C","PANTONE 548 C","PANTONE 5483 C","PANTONE 5487 C","PANTONE 549 C","PANTONE 5493 C","PANTONE 5497 C","PANTONE 550 C","PANTONE 5503 C","PANTONE 5507 C","PANTONE 551 C","PANTONE 5513 C","PANTONE 5517 C","PANTONE 552 C","PANTONE 5523 C","PANTONE 5527 C","PANTONE 553 C","PANTONE 5535 C","PANTONE 554 C","PANTONE 5545 C","PANTONE 555 C","PANTONE 5555 C","PANTONE 556 C","PANTONE 5565 C","PANTONE 557 C","PANTONE 5575 C","PANTONE 558 C","PANTONE 5585 C","PANTONE 559 C","PANTONE 5595 C","PANTONE 560 C","PANTONE 5605 C","PANTONE 561 C","PANTONE 5615 C","PANTONE 562 C","PANTONE 5625 C","PANTONE 563 C","PANTONE 5635 C","PANTONE 564 C","PANTONE 5645 C","PANTONE 565 C","PANTONE 5655 C","PANTONE 566 C","PANTONE 5665 C","PANTONE 567 C","PANTONE 568 C","PANTONE 569 C","PANTONE 570 C","PANTONE 571 C","PANTONE 572 C","PANTONE 573 C","PANTONE 574 C","PANTONE 5743 C","PANTONE 5747 C","PANTONE 575 C","PANTONE 5753 C","PANTONE 5757 C","PANTONE 576 C","PANTONE 5763 C","PANTONE 5767 C","PANTONE 577 C","PANTONE 5773 C","PANTONE 5777 C","PANTONE 578 C","PANTONE 5783 C","PANTONE 5787 C","PANTONE 579 C","PANTONE 5793 C","PANTONE 5797 C","PANTONE 580 C","PANTONE 5803 C","PANTONE 5807 C","PANTONE 581 C","PANTONE 5815 C","PANTONE 582 C","PANTONE 5825 C","PANTONE 583 C","PANTONE 5835 C","PANTONE 584 C","PANTONE 5845 C","PANTONE 585 C","PANTONE 5855 C","PANTONE 586 C","PANTONE 5865 C","PANTONE 587 C","PANTONE 5875 C","PANTONE 600 C","PANTONE 601 C","PANTONE 602 C","PANTONE 603 C","PANTONE 604 C","PANTONE 605 C","PANTONE 606 C","PANTONE 607 C","PANTONE 608 C","PANTONE 609 C","PANTONE 610 C","PANTONE 611 C","PANTONE 612 C","PANTONE 613 C","PANTONE 614 C","PANTONE 615 C","PANTONE 616 C","PANTONE 617 C","PANTONE 618 C","PANTONE 619 C","PANTONE 620 C","PANTONE 621 C","PANTONE 622 C","PANTONE 623 C","PANTONE 624 C","PANTONE 625 C","PANTONE 626 C","PANTONE 627 C","PANTONE 628 C","PANTONE 629 C","PANTONE 630 C","PANTONE 631 C","PANTONE 632 C","PANTONE 633 C","PANTONE 634 C","PANTONE 635 C","PANTONE 636 C","PANTONE 637 C","PANTONE 638 C","PANTONE 639 C","PANTONE 640 C","PANTONE 641 C","PANTONE 642 C","PANTONE 643 C","PANTONE 644 C","PANTONE 645 C","PANTONE 646 C","PANTONE 647 C","PANTONE 648 C","PANTONE 649 C","PANTONE 650 C","PANTONE 651 C","PANTONE 652 C","PANTONE 653 C","PANTONE 654 C","PANTONE 655 C","PANTONE 656 C","PANTONE 657 C","PANTONE 658 C","PANTONE 659 C","PANTONE 660 C","PANTONE 661 C","PANTONE 662 C","PANTONE 663 C","PANTONE 664 C","PANTONE 665 C","PANTONE 666 C","PANTONE 667 C","PANTONE 668 C","PANTONE 669 C","PANTONE 670 C","PANTONE 671 C","PANTONE 672 C","PANTONE 673 C","PANTONE 674 C","PANTONE 675 C","PANTONE 676 C","PANTONE 677 C","PANTONE 678 C","PANTONE 679 C","PANTONE 680 C","PANTONE 681 C","PANTONE 682 C","PANTONE 683 C","PANTONE 684 C","PANTONE 685 C","PANTONE 686 C","PANTONE 687 C","PANTONE 688 C","PANTONE 689 C","PANTONE 690 C","PANTONE 691 C","PANTONE 692 C","PANTONE 693 C","PANTONE 694 C","PANTONE 695 C","PANTONE 696 C","PANTONE 697 C","PANTONE 698 C","PANTONE 699 C","PANTONE 700 C","PANTONE 701 C","PANTONE 702 C","PANTONE 703 C","PANTONE 704 C","PANTONE 705 C","PANTONE 706 C","PANTONE 707 C","PANTONE 708 C","PANTONE 709 C","PANTONE 710 C","PANTONE 711 C","PANTONE 712 C","PANTONE 713 C","PANTONE 714 C","PANTONE 715 C","PANTONE 716 C","PANTONE 717 C","PANTONE 718 C","PANTONE 719 C","PANTONE 720 C","PANTONE 721 C","PANTONE 722 C","PANTONE 723 C","PANTONE 724 C","PANTONE 725 C","PANTONE 726 C","PANTONE 727 C","PANTONE 728 C","PANTONE 729 C","PANTONE 730 C","PANTONE 731 C","PANTONE 732 C","PANTONE 7401 C","PANTONE 7402 C","PANTONE 7403 C","PANTONE 7404 C","PANTONE 7405 C","PANTONE 7406 C","PANTONE 7407 C","PANTONE 7408 C","PANTONE 7409 C","PANTONE 7410 C","PANTONE 7411 C","PANTONE 7412 C","PANTONE 7413 C","PANTONE 7414 C","PANTONE 7415 C","PANTONE 7416 C","PANTONE 7417 C","PANTONE 7418 C","PANTONE 7419 C","PANTONE 7420 C","PANTONE 7421 C","PANTONE 7422 C","PANTONE 7423 C","PANTONE 7424 C","PANTONE 7425 C","PANTONE 7426 C","PANTONE 7427 C","PANTONE 7428 C","PANTONE 7429 C","PANTONE 7430 C","PANTONE 7431 C","PANTONE 7432 C","PANTONE 7433 C","PANTONE 7434 C","PANTONE 7435 C","PANTONE 7436 C","PANTONE 7437 C","PANTONE 7438 C","PANTONE 7439 C","PANTONE 7440 C","PANTONE 7441 C","PANTONE 7442 C","PANTONE 7443 C","PANTONE 7444 C","PANTONE 7445 C","PANTONE 7446 C","PANTONE 7447 C","PANTONE 7448 C","PANTONE 7449 C","PANTONE 7450 C","PANTONE 7451 C","PANTONE 7452 C","PANTONE 7453 C","PANTONE 7454 C","PANTONE 7455 C","PANTONE 7456 C","PANTONE 7457 C","PANTONE 7458 C","PANTONE 7459 C","PANTONE 7460 C","PANTONE 7461 C","PANTONE 7462 C","PANTONE 7463 C","PANTONE 7464 C","PANTONE 7465 C","PANTONE 7466 C","PANTONE 7467 C","PANTONE 7468 C","PANTONE 7469 C","PANTONE 7470 C","PANTONE 7471 C","PANTONE 7472 C","PANTONE 7473 C","PANTONE 7474 C","PANTONE 7475 C","PANTONE 7476 C","PANTONE 7477 C","PANTONE 7478 C","PANTONE 7479 C","PANTONE 7480 C","PANTONE 7481 C","PANTONE 7482 C","PANTONE 7483 C","PANTONE 7484 C","PANTONE 7485 C","PANTONE 7486 C","PANTONE 7487 C","PANTONE 7488 C","PANTONE 7489 C","PANTONE 7490 C","PANTONE 7491 C","PANTONE 7492 C","PANTONE 7493 C","PANTONE 7494 C","PANTONE 7495 C","PANTONE 7496 C","PANTONE 7497 C","PANTONE 7498 C","PANTONE 7499 C","PANTONE 7500 C","PANTONE 7501 C","PANTONE 7502 C","PANTONE 7503 C","PANTONE 7504 C","PANTONE 7505 C","PANTONE 7506 C","PANTONE 7507 C","PANTONE 7508 C","PANTONE 7509 C","PANTONE 7510 C","PANTONE 7511 C","PANTONE 7512 C","PANTONE 7513 C","PANTONE 7514 C","PANTONE 7515 C","PANTONE 7516 C","PANTONE 7517 C","PANTONE 7518 C","PANTONE 7519 C","PANTONE 7520 C","PANTONE 7521 C","PANTONE 7522 C","PANTONE 7523 C","PANTONE 7524 C","PANTONE 7525 C","PANTONE 7526 C","PANTONE 7527 C","PANTONE 7528 C","PANTONE 7529 C","PANTONE 7530 C","PANTONE 7531 C","PANTONE 7532 C","PANTONE 7533 C","PANTONE 7534 C","PANTONE 7535 C","PANTONE 7536 C","PANTONE 7537 C","PANTONE 7538 C","PANTONE 7539 C","PANTONE 7540 C","PANTONE 7541 C","PANTONE 7542 C","PANTONE 7543 C","PANTONE 7544 C","PANTONE 7545 C","PANTONE 7546 C","PANTONE 7547 C","PANTONE 8003 C","PANTONE 801 C","PANTONE 802 C","PANTONE 8021 C","PANTONE 803 C","PANTONE 804 C","PANTONE 805 C","PANTONE 806 C","PANTONE 8062 C","PANTONE 807 C","PANTONE 808 C","PANTONE 809 C","PANTONE 810 C","PANTONE 8100 C","PANTONE 811 C","PANTONE 812 C","PANTONE 813 C","PANTONE 814 C","PANTONE 8201 C","PANTONE 8281 C","PANTONE 8321 C","PANTONE 871 C","PANTONE 872 C","PANTONE 873 C","PANTONE 874 C","PANTONE 875 C","PANTONE 876 C","PANTONE 877 C","PANTONE Black 2 C","PANTONE Black 3 C","PANTONE Black 4 C","PANTONE Black 5 C","PANTONE Black 6 C","PANTONE Black 7 C","PANTONE Black C","PANTONE Black C 1","PANTONE Blue 072 C","PANTONE Blue 072 C 1","PANTONE Cool Gray 1 C","PANTONE Cool Gray 10 C","PANTONE Cool Gray 11 C","PANTONE Cool Gray 2 C","PANTONE Cool Gray 3 C","PANTONE Cool Gray 4 C","PANTONE Cool Gray 5 C","PANTONE Cool Gray 6 C","PANTONE Cool Gray 7 C","PANTONE Cool Gray 8 C","PANTONE Cool Gray 9 C","PANTONE Green C","PANTONE Green C 1","PANTONE Hexachrome Black C","PANTONE Hexachrome Cyan C","PANTONE Hexachrome Green C","PANTONE Hexachrome Magenta C","PANTONE Hexachrome Orange C","PANTONE Hexachrome Yellow C","PANTONE Orange 021 C","PANTONE Orange 021 C 1","PANTONE Process Black C","PANTONE Process Blue C","PANTONE Process Blue C 1","PANTONE Process Cyan C","PANTONE Process Magenta C","PANTONE Process Yellow C","PANTONE Purple C","PANTONE Purple C 1","PANTONE Red 032 C","PANTONE Red 032 C 1","PANTONE Reflex Blue C","PANTONE Reflex Blue C 1","PANTONE Rhodamine Red C","PANTONE Rhodamine Red C 1","PANTONE Rubine Red C","PANTONE Rubine Red C 1","PANTONE Violet C","PANTONE Violet C 1","PANTONE Warm Gray 1 C","PANTONE Warm Gray 10 C","PANTONE Warm Gray 11 C","PANTONE Warm Gray 2 C","PANTONE Warm Gray 3 C","PANTONE Warm Gray 4 C","PANTONE Warm Gray 5 C","PANTONE Warm Gray 6 C","PANTONE Warm Gray 7 C","PANTONE Warm Gray 8 C","PANTONE Warm Gray 9 C","PANTONE Warm Red C","PANTONE Warm Red C 1","PANTONE Yellow 012 C","PANTONE Yellow C","PANTONE Yellow C 1"];
maxprec = 21;
if (activeDocument.documentColorSpace == "DocumentColorSpace.RGB")
{
	space = "RGB";
	cols=[[255,247,151],[255,244,83],[255,242.00000077486,4.00000023655593],[219.000002145767,197000003457069,0],[192.000003755093,174.000004827976,0],[149.000006318092,136.000007092953,0],[255,239.000000953674,111.000000983477],[255,234.000001251698,83.0000026524067],[255,229.000001549721,18.0000008270144],[255,221.000002026558,0],[240.00000089407,202.000003159046,0],[197.000003457069,169.000005125999,1.00000005913898],[173.000004887581,150.000006258488,0],[255,230.000001490116,116.000000685453],[255,227.00000166893,99.0000016987324],[255,224.000001847744,79.0000028908253],[255,210.000002682209,0],[222.000001966953,180.000004470348,7.000000057742],[196.000003516674,159.000005722046,6.00000011734664],[150.000006258488,129.000007510185,0],[255,227.00000166893,132.000007331371],[255,238.000001013279,187.000004053116],[255,222.000001966953,108.000001162291],[255,228.000001609325,156.00000590086],[255,210.000002682209,79.0000028908253],[255,212.000002563,120.000000447035],[255,196.000003516674,37.0000015944242],[253.000000119209,187.000004053116,48.0000009387732],[238.000001013279,178.000004589558,17.0000008866191],[213.000002503395,159.000005722046,15.0000000558794],[197.000003457069,150.000006258488,11.0000002942979],[179.000004529953,135.000007152557,7.000000057742],[173.000004887581,133.000007271767,5.00000017695129],[144.000006616116,109.000001102686,0],[255,231.000001430511,148.000006377697],[255,222.000001966953,117.000000625849],[255,212.000002563,87.0000024139881],[253.000000119209,184.00000423193,19.0000007674098],[231.000001430511,166.000005304813,20.0000007078052],[187.000004053116,140.000006854534,10.0000003539026],[136.000007092953,109.000001102686,0],[255,224.000001847744,155.000005960464],[255,219.000002145767,149.000006318092],[255,208.000002801418,123.000000268221],[255,207.000002861023,130.000007450581],[253.000000119209,191.000003814697,87.0000024139881],[253.000000119209,188.000003993511,95.000001937151],[251.000000238419,176.000004708767,52.0000007003546],[250.000000298023,166.000005304813,52.0000007003546],[245.000000596046,159.000005722046,26.0000003501773],[232.000001370907,148.000006377697,25.0000004097819],[200.000003278255,138.000006973743,17.0000008866191],[171.00000500679,113.000000864267,10.0000003539026],[138.000006973743,104.000001400709,0],[120.000000447035,82.0000027120113,0],[255,209.000002741814,139.000006914139],[253.000000119209,190.000003874302,86.0000024735928],[251.000000238419,176.000004708767,63.0000000447035],[248.000000417233,152.000006139278,29.0000001713634],[229.000001549721,142.000006735325,26.0000003501773],[178.000004589558,115.000000745058,14.000000115484],[135.000007152557,101.000001579523,0],[255,216.000002324581,167.000005245209],[253.000000119209,193.000003695488,129.000007510185],[253.000000119209,202.000003159046,144.000006616116],[251.000000238419,181.000004410744,103.000001460314],[251.000000238419,177.000004649162,97.0000018179417],[249.000000357628,163.000005483627,80.0000028312206],[248.000000417233,152.000006139278,40.0000014156103],[243.000000715256,143.00000667572,29.0000001713634],[222.000001966953,121.00000038743,28.000000230968],[209.000002741814,131.000007390976,22.0000005885959],[166.000005304813,96.0000018775463,12.0000002346933],[175.000004768372,110.000001043081,13.0000001750886],[102.000001519918,54.0000005811453,0],[255,224.000001847744,187.000004053116],[253.000000119209,205.000002980232,167.000005245209],[253.000000119209,204.000003039837,153.000006079674],[250.000000298023,180.000004470348,133.000007271767],[249.000000357628,162.000005543232,94.0000019967556],[248.000000417233,158.000005781651,89.0000022947788],[245.000000596046,128.00000756979,37.0000015944242],[246.000000536442,137.000007033348,51.0000007599592],[227.00000166893,111.000000983477,30.0000001117587],[232.000001370907,125.000000149012,29.0000001713634],[177.000004649162,92.0000021159649,17.0000008866191],[182.000004351139,102.000001519918,18.0000008270144],[118.000000566244,66.0000036656857,0],[156.00000590086,86.0000024735928,7.000000057742],[254.000000059605,220.000002086163,194.000003635883],[251.000000238419,188.000003993511,155.000005960464],[251.000000238419,187.000004053116,143.00000667572],[249.000000357628,171.00000500679,132.000007331371],[248.000000417233,156.00000590086,87.0000024139881],[247.000000476837,151.000006198883,98.000001758337],[245.000000596046,132.000007331371,38.0000015348196],[244.000000655651,124.000000208616,48.0000009387732],[244.000000655651,123.000000268221,32.0000018924475],[243.000000715256,116.000000685453,33.0000018328428],[208.000002801418,111.000000983477,26.0000003501773],[185.000004172325,89.0000022947788,21.0000006482005],[126.000000089407,67.000003606081,0],[153.000006079674,71.0000033676624,8.00000047311187],[252.000000178814,210.000002682209,193.000003695488],[249.000000357628,169.000005125999,137.000007033348],[246.000000536442,144.000006616116,93.0000020563602],[244.000000655651,120.000000447035,54.0000005811453],[232.000001370907,108.000001162291,31.0000000521541],[168.000005185604,77.0000030100346,16.0000009462237],[124.000000208616,58.0000003427267,0],[251.000000238419,201.000003218651,191.000003814697],[248.000000417233,175.000004768372,173.000004887581],[250.000000298023,197.000003457069,198.000003397465],[247.000000476837,160.000005662441,139.000006914139],[246.000000536442,157.000005841255,154.000006020069],[244.000000655651,136.000007092953,135.000007152557],[245.000000596046,134.000007212162,107.000001221895],[243.000000715256,119.000000506639,110.000001043081],[241.000000834465,99.0000016987324,93.0000020563602],[240.00000089407,81.000002771616,51.0000007599592],[241.000000834465,93.0000020563602,34.0000017732382],[238.000001013279,52.0000007003546,36.0000016540289],[227.00000166893,27.0000002905726,35.0000017136335],[217.000002264977,84.000002592802,30.0000001117587],[191.000003814697,49.0000008791685,26.0000003501773],[181.000004410744,18.0000008270144,27.0000002905726],[146.000006496906,60.0000002235174,6.00000011734664],[138.000006973743,31.0000000521541,3.00000005867332],[111.000000983477,18.0000008270144,0],[250.000000298023,200.000003278255,203.000003099442],[246.000000536442,160.000005662441,166.000005304813],[243.000000715256,118.000000566244,121.00000038743],[239.000000953674,62.0000001043081,66.0000036656857],[227.00000166893,24.0000004693866,54.0000005811453],[196.000003516674,18.0000008270144,48.0000009387732],[139.000006914139,15.0000000558794,4.00000023655593],[247.000000476837,178.000004589558,191.000003814697],[249.000000357628,196.000003516674,206.000002920628],[244.000000655651,143.00000667572,156.00000590086],[247.000000476837,170.000005066395,188.000003993511],[241.000000834465,100.000001639128,119.000000506639],[241.000000834465,111.000000983477,145.000006556511],[237.000001072884,24.0000004693866,73.0000032484531],[237.000001072884,21.0000006482005,86.0000024735928],[209.000002741814,18.0000008270144,66.0000036656857],[224.000001847744,19.0000007674098,79.0000028908253],[171.00000500679,5.00000017695129,52.0000007003546],[198.000003397465,12.0000002346933,70.0000034272671],[130.000007450581,0,36.0000016540289],[163.000005483627,2.00000011827797,52.0000007003546],[250.000000298023,202.000003159046,214.00000244379],[246.000000536442,162.000005543232,182.000004351139],[241.000000834465,95.000001937151,124.000000208616],[237.000001072884,22.0000005885959,79.0000028908253],[211.000002622604,17.0000008866191,69.0000034868717],[178.000004589558,8.00000047311187,56.000000461936],[152.000006139278,0,46.0000010579824],[248.000000417233,185.000004172325,205.000002980232],[243.000000715256,138.000006973743,178.000004589558],[239.000000953674,80.0000028312206,145.000006556511],[228.000001609325,14.000000115484,98.000001758337],[198.000003397465,6.00000011734664,81.000002771616],[163.000005483627,0,70.0000034272671],[134.000007212162,0,56.000000461936],[247.000000476837,175.000004768372,195.000003576279],[244.000000655651,144.000006616116,175.000004768372],[241.000000834465,109.000001102686,154.000006020069],[238.000001013279,44.0000011771917,116.000000685453],[219.000002145767,9.00000041350722,98.000001758337],[182.000004351139,0,80.0000028312206],[142.000006735325,12.0000002346933,58.0000003427267],[249.000000357628,198.000003397465,220.000002086163],[236.000001132488,131.000007390976,181.000004410744],[234.000001251698,68.0000035464764,152.000006139278],[202.000003159046,0,108.000001162291],[177.000004649162,0,92.0000021159649],[124.000000208616,0,64.0000037848949],[245.000000596046,162.000005543232,198.000003397465],[238.000001013279,128.00000756979,179.000004529953],[235.000001192093,82.0000027120113,157.000005841255],[236.000001132488,11.0000002942979,141.00000679493],[198.000003397465,0,111.000000983477],[156.00000590086,0,88.0000023543835],[122.000000327826,0,60.0000002235174],[247.000000476837,185.000004172325,212.000002563],[239.000000953674,149.000006318092,191.000003814697],[232.000001370907,119.000000506639,175.000004768372],[214.00000244379,12.0000002346933,140.000006854534],[175.000004768372,0,110.000001043081],[151.000006198883,0,93.0000020563602],[244.000000655651,191.000003814697,217.000002264977],[242.00000077486,197.000003457069,220.000002086163],[235.000001192093,153.000006079674,194.000003635883],[219.000002145767,135.000007152557,185.000004172325],[227.00000166893,126.000000089407,178.000004589558],[200.000003278255,89.0000022947788,161.000005602837],[215.000002384186,91.0000021755695,161.000005602837],[185.000004172325,47.0000009983778,146.000006496906],[201.000003218651,48.0000009387732,146.000006496906],[173.000004887581,32.0000018924475,142.000006735325],[181.000004410744,26.0000003501773,138.000006973743],[162.000005543232,25.0000004097819,132.000007331371],[130.000007450581,0,83.0000026524067],[133.000007271767,12.0000002346933,112.000000923872],[234.000001251698,191.000003814697,217.000002264977],[223.000001907349,170.000005066395,206.000002920628],[211.000002622604,140.000006854534,189.000003933907],[182.000004351139,63.0000000447035,151.000006198883],[169.000005125999,33.0000018328428,142.000006735325],[158.000005781651,33.0000018328428,139.000006914139],[126.000000089407,12.0000002346933,110.000001043081],[235.000001192093,212.000002563,231.000001430511],[215.000002384186,166.000005304813,204.000003039837],[191.000003814697,131.000007390976,185.000004172325],[157.000005841255,51.0000007599592,147.000006437302],[145.000006556511,39.000001475215,143.00000667572],[115.000000745058,20.0000007078052,114.000000804663],[230.000001490116,206.000002920628,228.000001609325],[202.000003159046,170.000005066395,208.000002801418],[195.000003576279,171.00000500679,210.000002682209],[179.000004529953,161.000005602837,206.000002920628],[212.000002563,174.000004827976,210.000002682209],[177.000004649162,143.00000667572,194.000003635883],[177.000004649162,149.000006318092,198.000003397465],[156.00000590086,141.00000679493,195.000003576279],[154.000006020069,91.0000021755695,164.000005424023],[149.000006318092,97.0000018179417,168.000005185604],[147.000006437302,111.000000983477,177.000004649162],[122.000000327826,104.000001400709,174.000004827976],[120.000000447035,29.0000001713634,126.000000089407],[127.000000029802,64.0000037848949,152.000006139278],[124.000000208616,65.0000037252903,153.000006079674],[82.0000027120113,46.0000010579824,145.000006556511],[112.000000923872,20.0000007078052,113.000000864267],[119.000000506639,39.000001475215,139.000006914139],[110.000001043081,41.0000013560057,141.00000679493],[84.000002592802,41.0000013560057,136.000007092953],[101.000001579523,3.00000005867332,96.0000018775463],[108.000001162291,32.0000018924475,127.000000029802],[108.000001162291,32.0000018924475,126.000000089407],[83.0000026524067,36.0000016540289,127.000000029802],[86.0000024735928,0,78.0000029504299],[84.000002592802,7.000000057742,91.0000021755695],[97.0000018179417,16.0000009462237,106.0000012815],[73.0000032484531,23.0000005289912,109.000001102686],[223.000001907349,215.000002384186,235.000001192093],[181.000004410744,178.000004589558,217.000002264977],[185.000004172325,178.000004589558,216.000002324581],[154.000006020069,155.000005960464,205.000002980232],[129.000007510185,119.000000506639,183.000004291534],[126.000000089407,129.000007510185,190.000003874302],[90.0000022351742,64.0000037848949,153.000006079674],[113.000000864267,111.000000983477,179.000004529953],[73.0000032484531,47.0000009983778,146.000006496906],[79.0000028908253,38.0000015348196,131.000007390976],[51.0000007599592,41.0000013560057,133.000007271767],[70.0000034272671,22.0000005885959,107.000001221895],[38.0000015348196,8.00000047311187,89.0000022947788],[173.000004887581,176.000004708767,216.000002324581],[152.000006139278,165.000005364418,212.000002563],[202.000003159046,217.000002264977,239.000000953674],[207.000002861023,224.000001847744,243.000000715256],[184.00000423193,208.000002801418,237.000001072884],[147.000006437302,152.000006139278,204.000003039837],[118.000000566244,133.000007271767,194.000003635883],[139.000006914139,164.000005424023,212.000002563],[176.000004708767,202.000003159046,234.000001251698],[90.0000022351742,135.000007152557,197.000003457069],[117.000000625849,129.000007510185,191.000003814697],[82.0000027120113,97.0000018179417,172.000004947186],[75.0000031292439,99.0000016987324,174.000004827976],[78.0000029504299,132.000007331371,196.000003516674],[0,92.0000021159649,171.00000500679],[39.000001475215,49.0000008791685,139.000006914139],[39.000001475215,54.0000005811453,145.000006556511],[35.0000017136335,62.0000001043081,153.000006079674],[27.0000002905726,66.0000036656857,152.000006139278],[34.0000017732382,31.0000000521541,114.000000804663],[35.0000017136335,47.0000009983778,132.000007331371],[33.0000018328428,54.0000005811453,139.000006914139],[19.0000007674098,61.0000001639128,141.00000679493],[25.0000004097819,57.0000004023314,137.000007033348],[29.0000001713634,17.0000008866191,96.0000018775463],[30.0000001117587,33.0000018328428,113.000000864267],[28.000000230968,38.0000015348196,116.000000685453],[6.00000011734664,52.0000007003546,122.000000327826],[1.00000005913898,58.0000003427267,129.000007510185],[15.0000000558794,0,78.0000029504299],[21.0000006482005,20.0000007078052,95.000001937151],[17.0000008866191,23.0000005289912,94.0000019967556],[0,36.0000016540289,93.0000020563602],[0,45.0000011175871,106.0000012815],[180.000004470348,213.000002503395,240.00000089407],[150.000006258488,192.000003755093,230.000001490116],[81.000002771616,144.000006616116,205.000002980232],[0,73.0000032484531,144.000006616116],[0,61.0000001639128,125.000000149012],[0,45.0000011175871,98.000001758337],[159.000005722046,203.000003099442,237.000001072884],[108.000001162291,173.000004887581,223.000001907349],[0,124.000000208616,194.000003635883],[0,93.0000020563602,170.000005066395],[0,83.0000026524067,155.000005960464],[0,75.0000031292439,141.00000679493],[0,43.0000012367964,92.0000021159649],[185.000004172325,224.000001847744,247.000000476837],[139.000006914139,210.000002682209,244.000000655651],[164.000005424023,214.00000244379,244.000000655651],[84.000002592802,188.000003993511,235.000001192093],[120.000000447035,189.000003933907,232.000001370907],[0,150.000006258488,214.00000244379],[0,103.000001460314,177.000004649162],[0,118.000000566244,191.000003814697],[0,85.0000025331974,150.000006258488],[0,105.000001341105,170.000005066395],[0,68.0000035464764,124.000000208616],[0,82.0000027120113,136.000007092953],[0,45.0000011175871,86.0000024735928],[0,58.0000003427267,99.0000016987324],[114.000000804663,205.000002980232,244.000000655651],[173.000004887581,224.000001847744,237.000001072884],[19.0000007674098,181.000004410744,234.000001251698],[80.0000028312206,200.000003278255,232.000001370907],[0,157.000005841255,220.000002086163],[0,164.000005424023,227.00000166893],[0,120.000000447035,193.000003695488],[0,129.000007510185,198.000003397465],[0,101.000001579523,164.000005424023],[0,114.000000804663,174.000004827976],[0,84.000002592802,128.00000756979],[0,90.0000022351742,132.000007331371],[0,63.0000000447035,95.000001937151],[0,73.0000032484531,99.0000016987324],[173.000004887581,223.000001907349,232.000001370907],[112.000000923872,205.000002980232,227.00000166893],[0,188.000003993511,228.000001609325],[0,120.000000447035,174.000004827976],[0,104.000001400709,146.000006496906],[0,73.0000032484531,96.0000018775463],[137.000007033348,212.000002563,226.000001728535],[138.000006973743,211.000002622604,223.000001907349],[65.0000037252903,196.000003516674,220.000002086163],[70.0000034272671,195.000003576279,210.000002682209],[0,174.000004827976,219.000002145767],[0,181.000004410744,204.000003039837],[0,154.000006020069,200.000003278255],[0,159.000005722046,194.000003635883],[0,131.000007390976,168.000005185604],[0,140.000006854534,168.000005185604],[0,113.000000864267,143.00000667572],[0,120.000000447035,138.000006973743],[0,79.0000028908253,90.0000022351742],[0,83.0000026524067,93.0000020563602],[206.000002920628,235.000001192093,234.000001251698],[154.000006020069,215.000002384186,219.000002145767],[113.000000864267,203.000003099442,210.000002682209],[0,160.000005662441,175.000004768372],[0,139.000006914139,153.000006079674],[0,124.000000208616,133.000007271767],[0,107.000001221895,110.000001043081],[181.000004410744,225.000001788139,225.000001788139],[158.000005781651,216.000002324581,213.000002503395],[166.000005304813,218.000002205372,212.000002563],[142.000006735325,210.000002682209,202.000003159046],[103.000001460314,199.00000333786,198.000003397465],[131.000007390976,207.000002861023,202.000003159046],[126.000000089407,205.000002980232,195.000003576279],[97.0000018179417,197.000003457069,186.00000411272],[0,177.000004649162,176.000004708767],[34.0000017732382,188.000003993511,185.000004172325],[53.0000006407499,189.000003933907,178.000004589558],[0,175.000004768372,158.000005781651],[0,147.000006437302,143.00000667572],[0,169.000005125999,166.000005304813],[0,172.000004947186,161.000005602837],[0,160.000005662441,142.000006735325],[0,126.000000089407,122.000000327826],[0,149.000006318092,143.00000667572],[0,158.000005781651,147.000006437302],[0,142.000006735325,126.000000089407],[0,108.000001162291,103.000001460314],[0,108.000001162291,100.000001639128],[0,140.000006854534,127.000000029802],[0,113.000000864267,97.0000018179417],[0,89.0000022947788,83.0000026524067],[0,77.0000030100346,66.0000036656857],[0,87.0000024139881,70.0000034272671],[0,72.0000033080578,58.0000003427267],[192.000003755093,228.000001609325,218.000002205372],[177.000004649162,222.000001966953,210.000002682209],[143.00000667572,210.000002682209,197.000003457069],[0,162.000005543232,137.000007033348],[0,128.00000756979,102.000001519918],[0,105.000001341105,81.000002771616],[175.000004768372,221.000002026558,210.000002682209],[165.000005364418,217.000002264977,201.000003218651],[133.000007271767,206.000002920628,188.000003993511],[139.000006914139,207.000002861023,186.00000411272],[0,177.000004649162,147.000006437302],[93.0000020563602,194.000003635883,165.000005364418],[0,155.000005960464,122.000000327826],[0,176.000004708767,133.000007271767],[0,130.000007450581,101.000001579523],[0,138.000006973743,94.0000019967556],[0,111.000000983477,81.000002771616],[0,112.000000923872,74.0000031888485],[0,87.0000024139881,60.0000002235174],[0,80.0000028312206,47.0000009983778],[186.00000411272,224.000001847744,205.000002980232],[158.000005781651,213.000002503395,188.000003993511],[115.000000745058,198.000003397465,161.000005602837],[0,161.000005602837,96.0000018775463],[0,136.000007092953,81.000002771616],[0,112.000000923872,60.0000002235174],[0,72.0000033080578,18.0000008270144],[211.000002622604,235.000001192093,219.000002145767],[186.00000411272,224.000001847744,201.000003218651],[159.000005722046,213.000002503395,181.000004410744],[0,177.000004649162,90.0000022351742],[0,169.000005125999,79.0000028908253],[0,133.000007271767,63.0000000447035],[0,98.000001758337,37.0000015944242],[189.000003933907,222.000001966953,177.000004649162],[167.000005245209,213.000002503395,157.000005841255],[115.000000745058,193.000003695488,103.000001460314],[84.000002592802,185.000004172325,72.0000033080578],[74.0000031888485,169.000005125999,66.0000036656857],[67.000003606081,149.000006318092,57.0000004023314],[56.000000461936,124.000000208616,43.0000012367964],[225.000001788139,237.000001072884,195.000003576279],[208.000002801418,228.000001609325,166.000005304813],[179.000004529953,216.000002324581,140.000006854534],[122.000000327826,193.000003695488,66.0000036656857],[109.000001102686,179.000004529953,63.0000000447035],[93.0000020563602,151.000006198883,50.0000008195639],[79.0000028908253,110.000001043081,24.0000004693866],[231.000001430511,239.000000953674,188.000003993511],[218.000002205372,231.000001430511,162.000005543232],[200.000003278255,223.000001907349,142.000006735325],[160.000005662441,206.000002920628,103.000001460314],[140.000006854534,198.000003397465,63.0000000447035],[120.000000447035,162.000005543232,47.0000009983778],[86.0000024735928,108.000001162291,17.0000008866191],[237.000001072884,237.000001072884,138.000006973743],[228.000001609325,231.000001430511,108.000001162291],[214.00000244379,224.000001847744,61.0000001639128],[193.000003695488,215.000002384186,47.0000009983778],[178.000004589558,187.000004053116,30.0000001117587],[159.000005722046,166.000005304813,23.0000005289912],[129.000007510185,124.000000208616,0],[244.000000655651,240.00000089407,142.000006735325],[235.000001192093,234.000001251698,102.000001519918],[226.000001728535,230.000001490116,91.0000021755695],[213.000002503395,224.000001847744,77.0000030100346],[194.000003635883,205.000002980232,35.0000017136335],[163.000005483627,165.000005364418,16.0000009462237],[141.00000679493,139.000006914139,0],[251.000000238419,242.00000077486,144.000006616116],[255,243.000000715256,115.000000745058],[246.000000536442,237.000001072884,95.000001937151],[253.000000119209,239.000000953674,66.0000036656857],[242.00000077486,235.000001192093,69.0000034868717],[247.000000476837,236.000001132488,0],[235.000001192093,231.000001430511,41.0000013560057],[243.000000715256,234.000001251698,0],[212.000002563,209.000002741814,15.0000000558794],[195.000003576279,182.000004351139,0],[184.00000423193,179.000004529953,8.00000047311187],[168.000005185604,153.000006079674,0],[164.000005424023,154.000006020069,0],[122.000000327826,111.000000983477,0],[218.000002205372,211.000002622604,204.000003039837],[203.000003099442,193.000003695488,182.000004351139],[187.000004053116,176.000004708767,163.000005483627],[161.000005602837,151.000006198883,137.000007033348],[136.000007092953,126.000000089407,110.000001043081],[105.000001341105,94.0000019967556,73.0000032484531],[217.000002264977,207.000002861023,202.000003159046],[197.000003457069,184.00000423193,177.000004649162],[179.000004529953,165.000005364418,158.000005781651],[157.000005841255,141.00000679493,133.000007271767],[135.000007152557,116.000000685453,106.0000012815],[104.000001400709,79.0000028908253,64.0000037848949],[38.0000015348196,17.0000008866191,0],[211.000002622604,210.000002682209,196.000003516674],[189.000003933907,188.000003993511,175.000004768372],[166.000005304813,166.000005304813,152.000006139278],[148.000006377697,147.000006437302,131.000007390976],[117.000000625849,117.000000625849,97.0000018179417],[95.000001937151,96.0000018775463,75.0000031292439],[3.00000005867332,24.0000004693866,13.0000001750886],[220.000002086163,221.000002026558,222.000001966953],[197.000003457069,198.000003397465,200.000003278255],[182.000004351139,184.00000423193,186.00000411272],[159.000005722046,161.000005602837,164.000005424023],[126.000000089407,128.00000756979,130.000007450581],[95.000001937151,96.0000018775463,98.000001758337],[39.000001475215,36.0000016540289,36.0000016540289],[228.000001609325,229.000001549721,230.000001490116],[207.000002861023,212.000002563,216.000002324581],[176.000004708767,182.000004351139,187.000004053116],[147.000006437302,155.000005960464,161.000005602837],[106.0000012815,115.000000745058,123.000000268221],[69.0000034868717,85.0000025331974,96.0000018775463],[22.0000005885959,39.000001475215,50.0000008195639],[234.000001251698,225.000001788139,220.000002086163],[219.000002145767,209.000002741814,205.000002980232],[195.000003576279,182.000004351139,177.000004649162],[151.000006198883,137.000007033348,129.000007510185],[91.0000021755695,88.0000023543835,54.0000005811453],[74.0000031888485,74.0000031888485,48.0000009387732],[63.0000000447035,62.0000001043081,41.0000013560057],[217.000002264977,226.000001728535,218.000002205372],[194.000003635883,205.000002980232,197.000003457069],[165.000005364418,179.000004529953,171.00000500679],[139.000006914139,155.000005960464,146.000006496906],[94.0000019967556,110.000001043081,102.000001519918],[76.0000030696392,90.0000022351742,82.0000027120113],[68.0000035464764,77.0000030100346,62.0000001043081],[82.0000027120113,79.0000028908253,38.0000015348196],[110.000001043081,83.0000026524067,0],[89.0000022947788,88.0000023543835,43.0000012367964],[156.00000590086,125.000000149012,13.0000001750886],[103.000001460314,100.000001639128,47.0000009983778],[177.000004649162,149.000006318092,58.0000003427267],[178.000004589558,170.000005066395,126.000000089407],[203.000003099442,182.000004351139,118.000000566244],[197.000003457069,193.000003695488,157.000005841255],[218.000002205372,199.00000333786,147.000006437302],[219.000002145767,215.000002384186,189.000003933907],[231.000001430511,216.000002324581,171.00000500679],[230.000001490116,229.000001549721,211.000002622604],[241.000000834465,229.000001549721,200.000003278255],[118.000000566244,97.0000018179417,0],[162.000005543232,136.000007092953,0],[194.000003635883,162.000005543232,4.00000023655593],[233.000001311302,214.00000244379,102.000001519918],[242.00000077486,225.000001788139,139.000006914139],[246.000000536442,231.000001430511,161.000005602837],[248.000000417233,237.000001072884,180.000004470348],[90.0000022351742,71.0000033676624,28.000000230968],[87.0000024139881,39.000001475215,0],[127.000000029802,86.0000024735928,27.0000002905726],[155.000005960464,95.000001937151,14.000000115484],[158.000005781651,102.000001519918,20.0000007078052],[190.000003874302,133.000007271767,76.0000030696392],[206.000002920628,170.000005066395,122.000000327826],[212.000002563,166.000005304813,124.000000208616],[224.000001847744,194.000003635883,152.000006139278],[229.000001549721,193.000003695488,159.000005722046],[231.000001430511,210.000002682209,173.000004887581],[239.000000953674,214.00000244379,188.000003993511],[238.000001013279,225.000001788139,197.000003457069],[244.000000655651,226.000001728535,207.000002861023],[121.00000038743,68.0000035464764,0],[91.0000021755695,20.0000007078052,0],[176.000004708767,96.0000018775463,16.0000009462237],[144.000006616116,73.0000032484531,45.0000011175871],[206.000002920628,112.000000923872,25.0000004097819],[176.000004708767,118.000000566244,96.0000018775463],[251.000000238419,180.000004470348,128.00000756979],[196.000003516674,146.000006496906,126.000000089407],[253.000000119209,203.000003099442,163.000005483627],[218.000002205372,180.000004470348,163.000005483627],[254.000000059605,219.000002145767,188.000003993511],[229.000001549721,197.000003457069,182.000004351139],[254.000000059605,228.000001609325,201.000003218651],[238.000001013279,217.000002264977,204.000003039837],[83.0000026524067,48.0000009387732,26.0000003501773],[104.000001400709,50.0000008195639,31.0000000521541],[124.000000208616,53.0000006407499,32.0000018924475],[184.00000423193,139.000006914139,115.000000745058],[216.000002324581,181.000004410744,163.000005483627],[229.000001549721,204.000003039837,188.000003993511],[239.000000953674,223.000001907349,210.000002682209],[122.000000327826,22.0000005885959,0],[179.000004529953,35.0000017136335,23.0000005289912],[238.000001013279,50.0000008195639,36.0000016540289],[247.000000476837,156.00000590086,136.000007092953],[249.000000357628,180.000004470348,166.000005304813],[251.000000238419,199.00000333786,189.000003933907],[253.000000119209,221.000002026558,213.000002503395],[100.000001639128,34.0000017732382,0],[137.000007033348,49.0000008791685,1.00000005913898],[180.000004470348,83.0000026524067,64.0000037848949],[233.000001311302,152.000006139278,155.000005960464],[249.000000357628,186.00000411272,191.000003814697],[251.000000238419,204.000003039837,204.000003039837],[252.000000178814,219.000002145767,216.000002324581],[89.0000022947788,31.0000000521541,0],[84.000002592802,25.0000004097819,0],[124.000000208616,59.0000002831221,0],[147.000006437302,79.0000028908253,70.0000034272671],[144.000006616116,77.0000030100346,3.00000005867332],[175.000004768372,110.000001043081,101.000001579523],[223.000001907349,158.000005781651,157.000005841255],[199.00000333786,141.00000679493,134.000007212162],[241.000000834465,190.000003874302,190.000003874302],[225.000001788139,181.000004410744,178.000004589558],[247.000000476837,212.000002563,208.000002801418],[234.000001251698,201.000003218651,195.000003576279],[253.000000119209,229.000001549721,223.000001907349],[244.000000655651,222.000001966953,214.00000244379],[87.0000024139881,28.000000230968,31.0000000521541],[118.000000566244,33.0000018328428,35.0000017136335],[138.000006973743,37.0000015944242,41.0000013560057],[221.000002026558,155.000005960464,165.000005364418],[237.000001072884,180.000004470348,192.000003755093],[250.000000298023,204.000003039837,210.000002682209],[252.000000178814,218.000002205372,220.000002086163],[98.000001758337,26.0000003501773,75.0000031292439],[92.0000021159649,41.0000013560057,70.0000034272671],[134.000007212162,33.0000018328428,116.000000685453],[120.000000447035,73.0000032484531,106.0000012815],[154.000006020069,77.0000030100346,158.000005781651],[149.000006318092,110.000001043081,142.000006735325],[210.000002682209,145.000006556511,191.000003814697],[180.000004470348,147.000006437302,177.000004649162],[228.000001609325,172.000004947186,206.000002920628],[208.000002801418,181.000004410744,201.000003218651],[239.000000953674,196.000003516674,220.000002086163],[230.000001490116,211.000002622604,220.000002086163],[251.000000238419,217.000002264977,232.000001370907],[237.000001072884,226.000001728535,232.000001370907],[90.0000022351742,32.0000018924475,73.0000032484531],[76.0000030696392,36.0000016540289,50.0000008195639],[108.000001162291,39.000001475215,105.000001341105],[95.000001937151,57.0000004023314,68.0000035464764],[124.000000208616,43.0000012367964,131.000007390976],[144.000006616116,117.000000625849,120.000000447035],[184.00000423193,144.000006616116,194.000003635883],[186.00000411272,163.000005483627,171.00000500679],[206.000002920628,168.000005185604,206.000002920628],[209.000002741814,188.000003993511,195.000003576279],[222.000001966953,193.000003695488,220.000002086163],[225.000001788139,212.000002563,213.000002503395],[234.000001251698,217.000002264977,234.000001251698],[236.000001132488,229.000001549721,227.00000166893],[83.0000026524067,46.0000010579824,99.0000016987324],[0,33.0000018328428,91.0000021755695],[101.000001579523,45.0000011175871,137.000007033348],[54.0000005811453,60.0000002235174,116.000000685453],[106.0000012815,44.0000011771917,145.000006556511],[84.000002592802,98.000001758337,146.000006496906],[155.000005960464,125.000000149012,185.000004172325],[145.000006556511,148.000006377697,182.000004351139],[186.00000411272,157.000005841255,202.000003159046],[181.000004410744,187.000004053116,212.000002563],[204.000003039837,178.000004589558,213.000002503395],[201.000003218651,206.000002920628,225.000001788139],[223.000001907349,204.000003039837,228.000001609325],[223.000001907349,222.000001966953,233.000001311302],[24.0000004693866,60.0000002235174,71.0000033676624],[30.0000001117587,65.0000037252903,100.000001639128],[23.0000005289912,74.0000031888485,124.000000208616],[149.000006318092,168.000005185604,202.000003159046],[174.000004827976,188.000003993511,214.00000244379],[195.000003576279,208.000002801418,227.00000166893],[220.000002086163,226.000001728535,237.000001072884],[0,43.0000012367964,84.000002592802],[0,39.000001475215,76.0000030696392],[0,55.0000005215406,104.000001400709],[58.0000003427267,110.000001043081,143.00000667572],[0,70.0000034272671,127.000000029802],[93.0000020563602,135.000007152557,161.000005602837],[86.0000024735928,159.000005722046,211.000002622604],[127.000000029802,161.000005602837,182.000004351139],[143.00000667572,195.000003576279,233.000001311302],[185.000004172325,199.00000333786,212.000002563],[172.000004947186,212.000002563,241.000000834465],[204.000003039837,214.00000244379,223.000001907349],[194.000003635883,224.000001847744,246.000000536442],[216.000002324581,227.00000166893,233.000001311302],[0,50.0000008195639,77.0000030100346],[0,55.0000005215406,69.0000034868717],[0,33.0000018328428,36.0000016540289],[0,57.0000004023314,90.0000022351742],[0,106.0000012815,113.000000864267],[33.0000018328428,83.0000026524067,82.0000027120113],[0,68.0000035464764,106.0000012815],[56.000000461936,147.000006437302,155.000005960464],[89.0000022947788,122.000000327826,123.000000268221],[86.0000024735928,155.000005960464,189.000003933907],[114.000000804663,174.000004827976,182.000004351139],[146.000006496906,165.000005364418,164.000005424023],[126.000000089407,176.000004708767,204.000003039837],[156.00000590086,197.000003457069,201.000003218651],[174.000004827976,187.000004053116,186.00000411272],[160.000005662441,195.000003576279,218.000002205372],[195.000003576279,223.000001907349,224.000001847744],[197.000003457069,209.000002741814,207.000002861023],[194.000003635883,219.000002145767,232.000001370907],[216.000002324581,233.000001311302,232.000001370907],[213.000002503395,222.000001966953,220.000002086163],[17.0000008866191,68.0000035464764,50.0000008195639],[0,63.0000000447035,45.0000011175871],[0,84.000002592802,61.0000001639128],[52.0000007003546,113.000000864267,90.0000022351742],[0,103.000001460314,78.0000029504299],[97.0000018179417,144.000006616116,128.00000756979],[114.000000804663,163.000005483627,146.000006496906],[139.000006914139,174.000004827976,161.000005602837],[154.000006020069,194.000003635883,185.000004172325],[173.000004887581,199.00000333786,188.000003993511],[188.000003993511,214.00000244379,205.000002980232],[201.000003218651,218.000002205372,209.000002741814],[204.000003039837,224.000001847744,217.000002264977],[218.000002205372,229.000001549721,220.000002086163],[0,72.0000033080578,51.0000007599592],[0,38.0000015348196,22.0000005885959],[0,104.000001400709,87.0000024139881],[56.000000461936,99.0000016987324,81.000002771616],[0,133.000007271767,118.000000566244],[110.000001043081,136.000007092953,120.000000447035],[116.000000685453,199.00000333786,184.00000423193],[159.000005722046,173.000004887581,158.000005781651],[158.000005781651,216.000002324581,210.000002682209],[188.000003993511,197.000003457069,186.00000411272],[194.000003635883,229.000001549721,224.000001847744],[204.000003039837,212.000002563,202.000003159046],[217.000002264977,238.000001013279,230.000001490116],[217.000002264977,224.000001847744,216.000002324581],[0,79.0000028908253,57.0000004023314],[0,125.000000149012,104.000001400709],[0,146.000006496906,126.000000089407],[130.000007450581,206.000002920628,193.000003695488],[171.00000500679,220.000002086163,212.000002563],[194.000003635883,229.000001549721,222.000001966953],[217.000002264977,238.000001013279,232.000001370907],[69.0000034868717,90.0000022351742,33.0000018328428],[51.0000007599592,70.0000034272671,13.0000001750886],[58.0000003427267,76.0000030696392,0],[76.0000030696392,114.000000804663,29.0000001713634],[86.0000024735928,100.000001639128,35.0000017136335],[103.000001460314,119.000000506639,24.0000004693866],[92.0000021159649,135.000007152557,39.000001475215],[114.000000804663,122.000000327826,53.0000006407499],[148.000006377697,155.000005960464,81.000002771616],[179.000004529953,204.000003039837,148.000006377697],[158.000005781651,163.000005483627,116.000000685453],[176.000004708767,181.000004410744,121.00000038743],[195.000003576279,215.000002384186,164.000005424023],[184.00000423193,188.000003993511,155.000005960464],[210.000002682209,214.00000244379,171.00000500679],[206.000002920628,224.000001847744,179.000004529953],[206.000002920628,208.000002801418,180.000004470348],[221.000002026558,224.000001847744,189.000003933907],[219.000002145767,232.000001370907,196.000003516674],[223.000001907349,225.000001788139,206.000002920628],[240.00000089407,240.00000089407,216.000002324581],[103.000001460314,98.000001758337,0],[91.0000021755695,86.0000024735928,0],[139.000006914139,141.00000679493,9.00000041350722],[132.000007331371,122.000000327826,24.0000004693866],[175.000004768372,188.000003993511,34.0000017732382],[170.000005066395,159.000005722046,78.0000029504299],[217.000002264977,218.000002205372,86.0000024735928],[191.000003814697,182.000004351139,120.000000447035],[226.000001728535,228.000001609325,119.000000506639],[217.000002264977,211.000002622604,164.000005424023],[236.000001132488,237.000001072884,148.000006377697],[227.00000166893,222.000001966953,182.000004351139],[244.000000655651,243.000000715256,173.000004887581],[231.000001430511,226.000001728535,183.000004291534],[255,250.000000298023,196.000003516674],[255,249.000000357628,173.000004887581],[255,247.000000476837,153.000006079674],[255,241.000000834465,110.000001043081],[253.000000119209,234.000001251698,51.0000007599592],[244.000000655651,220.000002086163,0],[231.000001430511,207.000002861023,0],[253.000000119209,247.000000476837,213.000002503395],[252.000000178814,243.000000715256,185.000004172325],[248.000000417233,237.000001072884,155.000005960464],[245.000000596046,232.000001370907,129.000007510185],[235.000001192093,215.000002384186,34.0000017732382],[215.000002384186,195.000003576279,0],[192.000003755093,173.000004887581,0],[246.000000536442,241.000000834465,205.000002980232],[242.00000077486,232.000001370907,187.000004053116],[236.000001132488,223.000001907349,167.000005245209],[220.000002086163,206.000002920628,135.000007152557],[192.000003755093,174.000004827976,44.0000011771917],[164.000005424023,148.000006377697,0],[143.00000667572,129.000007510185,0],[214.00000244379,233.000001311302,225.000001788139],[185.000004172325,218.000002205372,204.000003039837],[157.000005841255,200.000003278255,186.00000411272],[118.000000566244,174.000004827976,153.000006079674],[77.0000030100346,145.000006556511,122.000000327826],[0,92.0000021159649,66.0000036656857],[0,56.000000461936,30.0000001117587],[204.000003039837,234.000001251698,238.000001013279],[163.000005483627,219.000002145767,230.000001490116],[126.000000089407,208.000002801418,224.000001847744],[38.0000015348196,188.000003993511,214.00000244379],[0,168.000005185604,203.000003099442],[0,138.000006973743,176.000004708767],[0,118.000000566244,152.000006139278],[168.000005185604,221.000002026558,232.000001370907],[131.000007390976,210.000002682209,228.000001609325],[98.000001758337,202.000003159046,227.00000166893],[0,182.000004351139,221.000002026558],[0,165.000005364418,217.000002264977],[0,143.00000667572,197.000003457069],[0,127.000000029802,177.000004649162],[204.000003039837,222.000001966953,240.00000089407],[178.000004589558,206.000002920628,231.000001430511],[135.000007152557,178.000004589558,216.000002324581],[103.000001460314,153.000006079674,200.000003278255],[78.0000029504299,138.000006973743,190.000003874302],[0,85.0000025331974,149.000006318092],[0,52.0000007003546,104.000001400709],[220.000002086163,230.000001490116,243.000000715256],[184.00000423193,207.000002861023,233.000001311302],[145.000006556511,176.000004708767,213.000002503395],[114.000000804663,153.000006079674,198.000003397465],[0,82.0000027120113,149.000006318092],[0,61.0000001639128,120.000000447035],[0,47.0000009983778,101.000001579523],[214.00000244379,231.000001430511,247.000000476837],[189.000003933907,216.000002324581,241.000000834465],[173.000004887581,197.000003457069,231.000001430511],[115.000000745058,156.00000590086,210.000002682209],[4.00000023655593,108.000001162291,182.000004351139],[0,84.000002592802,158.000005781651],[0,75.0000031292439,145.000006556511],[232.000001370907,233.000001311302,245.000000596046],[222.000001966953,223.000001907349,241.000000834465],[194.000003635883,197.000003457069,224.000001847744],[162.000005543232,160.000005662441,199.00000333786],[115.000000745058,115.000000745058,168.000005185604],[81.000002771616,78.0000029504299,133.000007271767],[53.0000006407499,44.0000011771917,102.000001519918],[252.000000178814,227.00000166893,238.000001013279],[246.000000536442,212.000002563,229.000001549721],[237.000001072884,182.000004351139,211.000002622604],[229.000001549721,152.000006139278,194.000003635883],[220.000002086163,117.000000625849,174.000004827976],[196.000003516674,17.0000008866191,136.000007092953],[182.000004351139,0,114.000000804663],[244.000000655651,224.000001847744,237.000001072884],[240.00000089407,207.000002861023,227.00000166893],[234.000001251698,194.000003635883,220.000002086163],[215.000002384186,156.00000590086,195.000003576279],[188.000003993511,118.000000566244,172.000004947186],[169.000005125999,78.0000029504299,145.000006556511],[139.000006914139,0,90.0000022351742],[244.000000655651,214.00000244379,227.00000166893],[240.00000089407,196.000003516674,215.000002384186],[235.000001192093,183.000004291534,206.000002920628],[212.000002563,146.000006496906,179.000004529953],[192.000003755093,115.000000745058,157.000005841255],[160.000005662441,66.0000036656857,118.000000566244],[125.000000149012,0,73.0000032484531],[248.000000417233,218.000002205372,215.000002384186],[244.000000655651,200.000003278255,201.000003218651],[234.000001251698,180.000004470348,184.00000423193],[225.000001788139,162.000005543232,160.000005662441],[203.000003099442,126.000000089407,128.00000756979],[177.000004649162,96.0000018775463,98.000001758337],[157.000005841255,74.0000031888485,72.0000033080578],[252.000000178814,219.000002145767,218.000002205372],[250.000000298023,204.000003039837,205.000002980232],[248.000000417233,179.000004529953,186.00000411272],[246.000000536442,161.000005602837,168.000005185604],[229.000001549721,109.000001102686,123.000000268221],[206.000002920628,70.0000034272671,82.0000027120113],[180.000004470348,46.0000010579824,52.0000007003546],[254.000000059605,233.000001311302,229.000001549721],[252.000000178814,218.000002205372,213.000002503395],[249.000000357628,191.000003814697,192.000003755093],[246.000000536442,160.000005662441,165.000005364418],[243.000000715256,121.00000038743,127.000000029802],[241.000000834465,93.0000020563602,94.0000019967556],[231.000001430511,25.0000004097819,57.0000004023314],[255,220.000002086163,179.000004529953],[254.000000059605,210.000002682209,157.000005841255],[253.000000119209,193.000003695488,128.00000756979],[251.000000238419,175.000004768372,95.000001937151],[249.000000357628,157.000005841255,49.0000008791685],[240.00000089407,139.000006914139,29.0000001713634],[227.00000166893,127.000000029802,28.000000230968],[255,229.000001549721,193.000003695488],[250.000000298023,215.000002384186,166.000005304813],[244.000000655651,192.000003755093,130.000007450581],[229.000001549721,160.000005662441,77.0000030100346],[212.000002563,137.000007033348,28.000000230968],[171.00000500679,101.000001579523,13.0000001750886],[147.000006437302,84.000002592802,3.00000005867332],[249.000000357628,227.00000166893,194.000003635883],[241.000000834465,207.000002861023,164.000005424023],[229.000001549721,186.00000411272,131.000007390976],[211.000002622604,157.000005841255,96.0000018775463],[187.000004053116,129.000007510185,58.0000003427267],[136.000007092953,78.0000029504299,0],[117.000000625849,63.0000000447035,0],[255,242.00000077486,212.000002563],[255,236.000001132488,187.000004053116],[255,225.000001788139,146.000006496906],[255,225.000001788139,83.0000026524067],[255,221.000002026558,0],[255,207.000002861023,1.00000005913898],[229.000001549721,181.000004410744,58.0000003427267],[255,194.000003635883,34.0000017732382],[253.000000119209,184.00000423193,36.0000016540289],[252.000000178814,187.000004053116,126.000000089407],[251.000000238419,177.000004649162,99.0000016987324],[232.000001370907,151.000006198883,25.0000004097819],[236.000001132488,137.000007033348,29.0000001713634],[223.000001907349,140.000006854534,25.0000004097819],[252.000000178814,215.000002384186,203.000003099442],[245.000000596046,132.000007331371,102.000001519918],[242.00000077486,102.000001519918,73.0000032484531],[230.000001490116,107.000001221895,91.0000021755695],[205.000002980232,112.000000923872,103.000001460314],[199.00000333786,74.0000031888485,92.0000021159649],[120.000000447035,0,50.0000008195639],[254.000000059605,234.000001251698,230.000001490116],[244.000000655651,143.00000667572,155.000005960464],[241.000000834465,103.000001460314,129.000007510185],[222.000001966953,58.0000003427267,109.000001102686],[200.000003278255,8.00000047311187,80.0000028312206],[181.000004410744,9.00000041350722,56.000000461936],[132.000007331371,43.0000012367964,55.0000005215406],[251.000000238419,216.000002324581,224.000001847744],[241.000000834465,189.000003933907,215.000002384186],[233.000001311302,168.000005185604,192.000003755093],[220.000002086163,131.000007390976,166.000005304813],[209.000002741814,89.0000022947788,129.000007510185],[198.000003397465,74.0000031888485,119.000000506639],[168.000005185604,0,91.0000021755695],[242.00000077486,233.000001311302,243.000000715256],[233.000001311302,207.000002861023,228.000001609325],[211.000002622604,172.000004947186,209.000002741814],[199.00000333786,169.000005125999,208.000002801418],[177.000004649162,154.000006020069,201.000003218651],[165.000005364418,135.000007152557,190.000003874302],[140.000006854534,100.000001639128,170.000005066395],[235.000001192093,235.000001192093,246.000000536442],[199.00000333786,202.000003159046,230.000001490116],[168.000005185604,182.000004351139,217.000002264977],[147.000006437302,150.000006258488,202.000003159046],[99.0000016987324,97.0000018179417,154.000006020069],[96.0000018775463,82.0000027120113,113.000000864267],[72.0000033080578,24.0000004693866,45.0000011175871],[199.00000333786,213.000002503395,238.000001013279],[150.000006258488,180.000004470348,222.000001966953],[128.00000756979,156.00000590086,208.000002801418],[125.000000149012,166.000005304813,215.000002384186],[114.000000804663,154.000006020069,199.00000333786],[59.0000002831221,115.000000745058,185.000004172325],[111.000000983477,140.000006854534,192.000003755093],[220.000002086163,241.000000834465,247.000000476837],[137.000007033348,203.000003099442,223.000001907349],[80.0000028312206,179.000004529953,207.000002861023],[0,165.000005364418,227.00000166893],[0,148.000006377697,211.000002622604],[0,103.000001460314,171.00000500679],[0,53.0000006407499,94.0000019967556],[188.000003993511,228.000001609325,229.000001549721],[122.000000327826,204.000003039837,200.000003278255],[31.0000000521541,190.000003874302,201.000003218651],[0,174.000004827976,197.000003457069],[0,124.000000208616,177.000004649162],[0,101.000001579523,148.000006377697],[0,105.000001341105,144.000006616116],[182.000004351139,225.000001788139,221.000002026558],[115.000000745058,203.000003099442,199.00000333786],[45.0000011175871,175.000004768372,164.000005424023],[0,146.000006496906,159.000005722046],[90.0000022351742,154.000006020069,152.000006139278],[0,89.0000022947788,87.0000024139881],[0,85.0000025331974,104.000001400709],[207.000002861023,234.000001251698,222.000001966953],[116.000000685453,198.000003397465,156.00000590086],[99.0000016987324,194.000003635883,156.00000590086],[101.000001579523,194.000003635883,148.000006377697],[0,178.000004589558,116.000000685453],[0,98.000001758337,39.000001475215],[0,101.000001579523,58.0000003427267],[238.000001013279,246.000000536442,231.000001430511],[206.000002920628,230.000001490116,192.000003755093],[182.000004351139,219.000002145767,164.000005424023],[151.000006198883,206.000002920628,139.000006914139],[101.000001579523,179.000004529953,96.0000018775463],[103.000001460314,145.000006556511,70.0000034272671],[119.000000506639,142.000006735325,29.0000001713634],[212.000002563,219.000002145767,144.000006616116],[200.000003278255,213.000002503395,166.000005304813],[168.000005185604,195.000003576279,153.000006079674],[147.000006437302,164.000005424023,69.0000034868717],[109.000001102686,141.00000679493,35.0000017136335],[129.000007510185,128.00000756979,84.000002592802],[63.0000000447035,75.0000031292439,0],[255,246.000000536442,220.000002086163],[247.000000476837,237.000001072884,212.000002563],[241.000000834465,227.00000166893,197.000003457069],[232.000001370907,210.000002682209,161.000005602837],[199.00000333786,177.000004649162,139.000006914139],[166.000005304813,132.000007331371,98.000001758337],[137.000007033348,101.000001579523,50.0000008195639],[255,240.00000089407,216.000002324581],[255,228.000001609325,184.00000423193],[244.000000655651,209.000002741814,155.000005960464],[241.000000834465,196.000003516674,133.000007271767],[226.000001728535,168.000005185604,85.0000025331974],[194.000003635883,123.000000268221,19.0000007674098],[178.000004589558,112.000000923872,14.000000115484],[244.000000655651,206.000002920628,175.000004768372],[239.000000953674,191.000003814697,151.000006198883],[222.000001966953,159.000005722046,117.000000625849],[173.000004887581,101.000001579523,14.000000115484],[154.000006020069,81.000002771616,7.000000057742],[126.000000089407,84.000002592802,58.0000003427267],[87.0000024139881,67.000003606081,25.0000004097819],[253.000000119209,218.000002205372,199.00000333786],[227.00000166893,182.000004351139,172.000004947186],[213.000002503395,147.000006437302,137.000007033348],[205.000002980232,141.00000679493,126.000000089407],[188.000003993511,108.000001162291,80.0000028312206],[183.000004291534,119.000000506639,93.0000020563602],[171.00000500679,84.000002592802,16.0000009462237],[237.000001072884,231.000001430511,221.000002026558],[231.000001430511,222.000001966953,207.000002861023],[217.000002264977,207.000002861023,192.000003755093],[185.000004172325,171.00000500679,150.000006258488],[148.000006377697,134.000007212162,113.000000864267],[118.000000566244,100.000001639128,65.0000037252903],[75.0000031292439,57.0000004023314,0],[231.000001430511,224.000001847744,213.000002503395],[211.000002622604,202.000003159046,183.000004291534],[185.000004172325,176.000004708767,152.000006139278],[202.000003159046,206.000002920628,193.000003695488],[171.00000500679,181.000004410744,171.00000500679],[171.00000500679,174.000004827976,165.000005364418],[105.000001341105,106.0000012815,108.000001162291],[233.000001311302,238.000001013279,241.000000834465],[194.000003635883,209.000002741814,211.000002622604],[172.000004947186,184.00000423193,191.000003814697],[148.000006377697,160.000005662441,169.000005125999],[91.0000021755695,111.000000983477,123.000000268221],[65.0000037252903,89.0000022947788,104.000001400709],[22.0000005885959,41.0000013560057,52.0000007003546],[151.000006198883,148.000006377697,130.000007450581],[0,171.00000500679,223.000001907349],[172.000004947186,213.000002503395,138.000006973743],[198.000003397465,165.000005364418,140.000006854534],[255,245.000000596046,110.000001043081],[253.000000119209,209.000002741814,167.000005245209],[248.000000417233,171.00000500679,166.000005304813],[244.000000655651,153.000006079674,193.000003695488],[184.00000423193,141.00000679493,148.000006377697],[208.000002801418,99.0000016987324,165.000005364418],[0,181.000004410744,173.000004887581],[237.000001072884,232.000001370907,10.0000003539026],[255,227.00000166893,175.000004768372],[186.00000411272,177.000004649162,186.00000411272],[251.000000238419,200.000003278255,180.000004470348],[245.000000596046,152.000006139278,170.000005066395],[241.000000834465,115.000000745058,172.000004947186],[128.00000756979,113.000000864267,180.000004470348],[146.000006496906,181.000004410744,199.00000333786],[129.000007510185,173.000004887581,168.000005185604],[161.000005602837,182.000004351139,154.000006020069],[163.000005483627,145.000006556511,97.0000018179417],[180.000004470348,151.000006198883,90.0000022351742],[168.000005185604,153.000006079674,110.000001043081],[188.000003993511,155.000005960464,106.0000012815],[185.000004172325,151.000006198883,101.000001579523],[186.00000411272,135.000007152557,72.0000033080578],[167.000005245209,169.000005125999,172.000004947186],[71.0000033676624,66.0000036656857,32.0000018924475],[0,46.0000010579824,26.0000003501773],[65.0000037252903,48.0000009387732,0],[71.0000033676624,41.0000013560057,42.000001296401],[0,0,23.0000005289912],[84.000002592802,83.0000026524067,74.0000031888485],[38.0000015348196,28.000000230968,2.00000011827797],[38.0000015348196,28.000000230968,2.00000011827797],[28.000000230968,63.0000000447035,148.000006377697],[28.000000230968,63.0000000447035,148.000006377697],[239.000000953674,240.00000089407,240.00000089407],[128.00000756979,127.000000029802,131.000007390976],[113.000000864267,112.000000923872,115.000000745058],[230.000001490116,231.000001430511,232.000001370907],[216.000002324581,217.000002264977,218.000002205372],[201.000003218651,202.000003159046,204.000003039837],[190.000003874302,192.000003755093,194.000003635883],[186.00000411272,188.000003993511,190.000003874302],[173.000004887581,175.000004768372,178.000004589558],[160.000005662441,160.000005662441,164.000005424023],[145.000006556511,145.000006556511,148.000006377697],[0,168.000005185604,143.00000667572],[0,168.000005185604,143.00000667572],[33.0000018328428,29.0000001713634,30.0000001117587],[0,174.000004827976,239.000000953674],[0,169.000005125999,79.0000028908253],[237.000001072884,29.0000001713634,143.00000667572],[247.000000476837,144.000006616116,30.0000001117587],[255,238.000001013279,0],[247.000000476837,143.00000667572,30.0000001117587],[247.000000476837,143.00000667572,30.0000001117587],[35.0000017136335,31.0000000521541,32.0000018924475],[0,146.000006496906,207.000002861023],[0,146.000006496906,207.000002861023],[0,173.000004887581,239.000000953674],[236.000001132488,0,140.000006854534],[255,242.00000077486,0],[165.000005364418,68.0000035464764,153.000006079674],[165.000005364418,68.0000035464764,153.000006079674],[239.000000953674,65.0000037252903,53.0000006407499],[239.000000953674,65.0000037252903,53.0000006407499],[0,84.000002592802,164.000005424023],[0,84.000002592802,164.000005424023],[229.000001549721,64.0000037848949,151.000006198883],[229.000001549721,64.0000037848949,151.000006198883],[226.000001728535,1.00000005913898,119.000000506639],[226.000001728535,1.00000005913898,119.000000506639],[51.0000007599592,48.0000009387732,146.000006496906],[51.0000007599592,48.0000009387732,146.000006496906],[239.000000953674,233.000001311302,229.000001549721],[138.000006973743,121.00000038743,103.000001460314],[124.000000208616,106.0000012815,85.0000025331974],[233.000001311302,227.00000166893,219.000002145767],[216.000002324581,208.000002801418,199.00000333786],[202.000003159046,194.000003635883,184.00000423193],[191.000003814697,182.000004351139,172.000004947186],[187.000004053116,177.000004649162,165.000005364418],[172.000004947186,160.000005662441,149.000006318092],[161.000005602837,149.000006318092,137.000007033348],[153.000006079674,139.000006914139,125.000000149012],[242.00000077486,102.000001519918,49.0000008791685],[242.00000077486,102.000001519918,49.0000008791685],[255,232.000001370907,0],[255,238.000001013279,0],[255,238.000001013279,0]];
}else{
	space = "CMYK";
	cols=[[0,0,50.9999990463257,0],[0,0,79.0000021457672,0],[0,0,94.9999988079071,0],[0,2.99999713897705,100,18.0000007152557],[0,2.99999713897705,100,30.0000011920929],[0,2.99999713897705,100,50],[0,1.99999809265137,68.9999997615814,0],[0,4.00000214576721,79.0000021457672,0],[0,6.00000023841858,94.9999988079071,0],[0,10.0000023841858,100,0],[0,12.0000004768372,100,6.99999928474426],[0,11.0000014305115,100,26.9999980926514],[0,10.0000023841858,100,37.9999995231628],[0,6.99999928474426,66.0000026226044,0],[0,7.99999833106995,73.0000019073486,0],[0,9.00000333786011,80.0000011920929,0],[0,15.9999966621399,100,0],[0,18.0000007152557,100,14.9999976158142],[0,18.0000007152557,100,26.9999980926514],[0,12.0000004768372,100,49.0000009536743],[0,9.00000333786011,57.9999983310699,0],[0,5.0000011920929,31.0000002384186,0],[0,11.0000014305115,68.9999997615814,0],[0,9.00000333786011,44.9999988079071,0],[0,17.0000016689301,80.0000011920929,0],[0,17.0000016689301,62.0000004768372,0],[0,24.0000009536743,93.9999997615814,0],[0,28.9999961853027,91.0000026226044,0],[0,27.9999971389771,100,6.00000023841858],[0,27.9999971389771,100,18.0000007152557],[0,25.9999990463257,100,25.9999990463257],[0,26.9999980926514,100,34.0000033378601],[0,25,100,37.0000004768372],[0,26.9999980926514,100,50.9999990463257],[0,6.99999928474426,50,0],[0,11.0000014305115,64.9999976158142,0],[0,15.9999966621399,76.9999980926514,0],[0,30.0000011920929,100,0],[0,31.9999992847443,100,9.00000333786011],[0,27.9999971389771,100,30.0000011920929],[0,19.9999988079071,100,56.0000002384186],[0,11.0000014305115,44.9999988079071,0],[0,13.9999985694885,47.0000028610229,0],[0,18.9999997615814,60.0000023841858,0],[0,19.9999988079071,56.0000002384186,0],[0,26.9999980926514,75.9999990463257,0],[0,28.9999961853027,72.0000028610229,0],[0,35.0000023841858,89.9999976158142,0],[0,39.9999976158142,89.9999976158142,0],[0,41.9999957084656,100,0.99999904632568],[0,43.9999997615814,100,6.99999928474426],[0,37.0000004768372,100,23.0000019073486],[0,40.9999966621399,100,37.0000004768372],[0,26.9999980926514,100,54.0000021457672],[0,36.0000014305115,100,62.9999995231628],[0,18.9999997615814,50.9999990463257,0],[0,27.9999971389771,75.9999990463257,0],[0,35.0000023841858,85.0000023841858,0],[0,48.0000019073486,100,0],[0,47.0000028610229,100,7.99999833106995],[0,43.0000007152557,100,33.0000042915344],[0,27.9999971389771,100,56.0000002384186],[0,15.9999966621399,37.0000004768372,0],[0,26.9999980926514,54.0000021457672,0],[0,23.0000019073486,47.0000028610229,0],[0,33.0000042915344,67.0000016689301,0],[0,35.0000023841858,69.9999988079071,0],[0,41.9999957084656,76.9999980926514,0],[0,48.0000019073486,94.9999988079071,0],[0,50.9999990463257,100,0.99999904632568],[0,57.9999983310699,100,10.0000023841858],[0,46.0000038146973,100,18.0000007152557],[0,52.9999971389771,100,37.9999995231628],[0,46.0000038146973,100,34.0000033378601],[0,52.9999971389771,100,72.0000028610229],[0,12.0000004768372,27.9999971389771,0],[0,22.0000028610229,34.0000033378601,0],[0,22.0000028610229,41.9999957084656,0],[0,34.0000033378601,49.0000009536743,0],[0,43.0000007152557,69.9999988079071,0],[0,44.9999988079071,72.0000028610229,0],[0,61.0000014305115,97.0000028610229,0],[0,56.0000002384186,89.9999976158142,0],[0,66.0000026226044,100,6.99999928474426],[0,58.9999973773956,100,5.0000011920929],[0,62.0000004768372,100,31.9999992847443],[0,56.0000002384186,100,30.0000011920929],[0,51.9999980926514,100,63.9999985694885],[0,56.0000002384186,100,43.0000007152557],[0,14.9999976158142,22.0000028610229,0],[0,31.0000002384186,37.0000004768372,0],[0,31.0000002384186,43.9999997615814,0],[0,38.9999985694885,48.0000019073486,0],[0,46.0000038146973,73.0000019073486,0],[0,49.0000009536743,66.0000026226044,0],[0,58.9999973773956,95.9999978542328,0],[0,62.9999995231628,91.0000026226044,0],[0,63.9999985694885,100,0],[0,68.0000007152557,100,0],[0,60.0000023841858,100,17.0000016689301],[0,67.0000016689301,100,27.9999971389771],[0,56.9999992847443,100,58.9999973773956],[0,68.0000007152557,100,43.9999997615814],[0,19.9999988079071,19.9999988079071,0],[0,39.9999976158142,43.9999997615814,0],[0,52.9999971389771,68.0000007152557,0],[0,66.0000026226044,87.9999995231628,0],[0,68.9999997615814,100,4.00000214576721],[0,69.9999988079071,100,36.0000014305115],[0,64.9999976158142,100,60.0000023841858],[0,25,18.0000007152557,0],[0,37.9999995231628,20.9999978542328,0],[0,26.9999980926514,12.0000004768372,0],[0,44.9999988079071,39.9999976158142,0],[0,47.0000028610229,28.9999961853027,0],[0,57.9999983310699,36.0000014305115,0],[0,58.9999973773956,56.0000002384186,0],[0,67.0000016689301,50,0],[0,75.9999990463257,60.0000023841858,0],[0,83.9999973773956,87.9999995231628,0],[0,79.0000021457672,100,0],[0,93.9999997615814,100,0],[0,100,99.0000009536743,4.00000214576721],[0,79.0000021457672,100,11.0000014305115],[0,91.0000026226044,100,23.0000019073486],[0,100,95.9999978542328,27.9999971389771],[0,74.0000009536743,100,47.0000028610229],[0,89.9999976158142,100,50.9999990463257],[0,89.9999976158142,100,66.0000026226044],[0,25.9999990463257,10.0000023841858,0],[0,46.0000038146973,20.9999978542328,0],[0,68.0000007152557,40.9999966621399,0],[0,91.0000026226044,75.9999990463257,0],[0,100,81.0000002384186,4.00000214576721],[0,100,79.0000021457672,19.9999988079071],[0,97.0000028610229,100,50],[0,37.0000004768372,10.0000023841858,0],[0,27.9999971389771,6.99999928474426,0],[0,55.0000011920929,22.0000028610229,0],[0,40.9999966621399,9.00000333786011,0],[0,75.9999990463257,37.9999995231628,0],[0,70.9999978542328,19.9999988079071,0],[0,100,68.0000007152557,0],[0,100,55.0000011920929,0],[0,100,66.0000026226044,12.9999995231628],[0,100,56.9999992847443,5.0000011920929],[0,100,63.9999985694885,33.0000042915344],[0,100,56.0000002384186,18.9999997615814],[0,100,60.0000023841858,55.0000011920929],[0,100,60.0000023841858,37.0000004768372],[0,25,4.00000214576721,0],[0,44.9999988079071,10.0000023841858,0],[0,77.9999971389771,33.0000042915344,0],[0,100,62.0000004768372,0],[0,100,62.9999995231628,12.0000004768372],[0,100,62.9999995231628,28.9999961853027],[0,100,61.0000014305115,43.0000007152557],[0,34.0000033378601,2.99999713897705,0],[0,57.9999983310699,2.99999713897705,0],[0,83.9999973773956,9.00000333786011,0],[0,100,37.9999995231628,2.99999713897705],[0,100,43.0000007152557,18.9999997615814],[0,100,36.0000014305115,37.0000004768372],[0,100,34.0000033378601,52.9999971389771],[0,38.9999985694885,6.00000023841858,0],[0,55.0000011920929,7.99999833106995,0],[0,72.0000028610229,11.0000014305115,0],[0,94.9999988079071,26.9999980926514,0],[0,100,34.0000033378601,7.99999833106995],[0,100,35.0000023841858,26.9999980926514],[0,94.9999988079071,39.9999976158142,49.0000009536743],[0,27.9999971389771,0,0],[1.99999809265137,61.0000014305115,0,0],[0.99999904632568,87.9999995231628,0,0],[0,100,12.9999995231628,17.0000016689301],[0,100,14.9999976158142,30.0000011920929],[0,100,10.0000023841858,58.9999973773956],[0,46.0000038146973,0,0],[0.99999904632568,62.9999995231628,0,0],[0.99999904632568,82.9999983310699,0,0],[0,99.0000009536743,0,0],[0,100,6.99999928474426,18.9999997615814],[0,100,4.00000214576721,40.9999966621399],[0,100,14.9999976158142,60.0000023841858],[0,34.0000033378601,0,0],[0.99999904632568,51.9999980926514,0,0],[2.99999713897705,67.0000016689301,0,0],[11.0000014305115,100,0,0],[6.00000023841858,100,0,25.9999990463257],[5.0000011920929,100,0,39.9999976158142],[0.99999904632568,30.0000011920929,0,0],[1.99999809265137,26.9999980926514,0,0],[2.99999713897705,49.0000009536743,0,0],[10.0000023841858,56.9999992847443,0,0],[6.00000023841858,62.9999995231628,0,0],[18.9999997615814,79.0000021457672,0,0],[11.0000014305115,79.0000021457672,0,0],[26.9999980926514,94.9999988079071,0,0],[18.0000007152557,93.9999997615814,0,0],[34.0000033378601,100,0,0],[26.9999980926514,100,0,1.99999809265137],[33.0000042915344,100,0,7.99999833106995],[10.0000023841858,100,0,49.0000009536743],[37.0000004768372,100,0,25.9999990463257],[5.0000011920929,28.9999961853027,0,0],[9.00000333786011,37.9999995231628,0,0],[13.9999985694885,52.9999971389771,0,0],[28.9999961853027,89.9999976158142,0,0],[36.0000014305115,100,0,0],[39.9999976158142,100,0,1.99999809265137],[39.9999976158142,100,0,27.9999971389771],[5.0000011920929,18.0000007152557,0,0],[12.9999995231628,38.9999985694885,0,0],[24.0000009536743,56.0000002384186,0,0],[43.0000007152557,94.9999988079071,0,0],[50,100,0,0],[50.9999990463257,100,0,25],[6.99999928474426,19.9999988079071,0,0],[18.9999997615814,35.0000023841858,0,0],[22.0000028610229,33.0000042915344,0,0],[28.9999961853027,36.0000014305115,0,0],[13.9999985694885,34.0000033378601,0,0],[30.0000011920929,47.0000028610229,0,0],[30.0000011920929,43.0000007152557,0,0],[39.9999976158142,44.9999988079071,0,0],[43.0000007152557,75.9999990463257,0,0],[46.0000038146973,72.0000028610229,0,0],[46.0000038146973,62.9999995231628,0,0],[58.9999973773956,66.0000026226044,0,0],[55.0000011920929,100,0,14.9999976158142],[60.0000023841858,89.9999976158142,0,0],[61.0000014305115,88.9999985694885,0,0],[85.0000023841858,100,0,0],[51.9999980926514,100,0,25.9999990463257],[62.9999995231628,100,0,2.99999713897705],[68.9999997615814,100,0,1.99999809265137],[81.0000002384186,100,0,6.99999928474426],[48.0000019073486,100,0,39.9999976158142],[63.9999985694885,100,0,13.9999985694885],[62.9999995231628,100,0,14.9999976158142],[79.0000021457672,100,0,14.9999976158142],[44.9999988079071,100,0,55.0000011920929],[56.9999992847443,98.0000019073486,0,46.0000038146973],[58.9999973773956,100,0,31.9999992847443],[76.9999980926514,100,0,31.0000002384186],[10.0000023841858,13.9999985694885,0,0],[27.9999971389771,26.9999980926514,0,0],[25.9999990463257,27.9999971389771,0,0],[39.9999976158142,36.0000014305115,0,0],[54.0000021457672,56.0000002384186,0,0],[54.0000021457672,49.0000009536743,0,0],[79.0000021457672,89.9999976158142,0,0],[62.0000004768372,60.0000023841858,0,0],[88.9999985694885,100,0,0],[81.9999992847443,100,0,12.0000004768372],[95.9999978542328,100,0,10.0000023841858],[77.9999971389771,100,0,33.0000042915344],[91.0000026226044,100,0,49.0000009536743],[31.0000002384186,26.9999980926514,0,0],[39.9999976158142,30.0000011920929,0,0],[18.9999997615814,9.00000333786011,0,0],[17.0000016689301,6.00000023841858,0,0],[25.9999990463257,10.0000023841858,0,0],[43.0000007152557,37.0000004768372,0,0],[56.9999992847443,44.9999988079071,0,0],[44.9999988079071,28.9999961853027,0,0],[28.9999961853027,12.0000004768372,0,0],[67.0000016689301,40.9999966621399,0,0],[57.9999983310699,48.0000019073486,0,0],[76.9999980926514,68.0000007152557,0,0],[79.0000021457672,66.0000026226044,0,0],[70.9999978542328,41.9999957084656,0,0],[95.9999978542328,68.9999997615814,0,0],[100,95.9999978542328,0,7.99999833106995],[100,94.9999988079071,0,2.99999713897705],[100,91.0000026226044,0,0],[100,87.0000004768372,0,1.99999809265137],[100,100,0,27.9999971389771],[100,94.9999988079071,0,14.9999976158142],[100,92.0000016689301,0,10.0000023841858],[100,85.0000023841858,0,12.9999995231628],[100,87.9999995231628,0,13.9999985694885],[98.0000019073486,100,0,43.0000007152557],[100,97.0000028610229,0,30.0000011920929],[100,93.9999997615814,0,28.9999961853027],[100,81.9999992847443,0,30.0000011920929],[100,80.0000011920929,0,25.9999990463257],[100,100,0,57.9999983310699],[100,97.0000028610229,0,44.9999988079071],[100,93.9999997615814,0,47.0000028610229],[100,77.9999971389771,0,54.0000021457672],[100,77.9999971389771,0,43.9999997615814],[26.9999980926514,6.99999928474426,0,0],[38.9999985694885,13.9999985694885,0,0],[68.0000007152557,34.0000033378601,0,0],[100,72.0000028610229,0,18.0000007152557],[100,72.0000028610229,0,31.9999992847443],[100,68.0000007152557,0,54.0000021457672],[35.0000023841858,9.00000333786011,0,0],[55.0000011920929,18.9999997615814,0,0],[88.9999985694885,43.0000007152557,0,0],[100,66.0000026226044,0,1.99999809265137],[100,68.0000007152557,0,12.0000004768372],[100,67.0000016689301,0,23.0000019073486],[100,63.9999985694885,0,60.0000023841858],[25,1.99999809265137,0,0],[40.9999966621399,1.99999809265137,0,0],[33.0000042915344,2.99999713897705,0,0],[58.9999973773956,6.99999928474426,0,0],[49.0000009536743,11.0000014305115,0,0],[85.0000023841858,24.0000009536743,0,0],[100,56.9999992847443,0,1.99999809265137],[100,46.0000038146973,0,0],[100,57.9999983310699,0,20.9999978542328],[100,44.9999988079071,0,13.9999985694885],[100,56.9999992847443,0,39.9999976158142],[100,44.9999988079071,0,37.0000004768372],[100,46.0000038146973,0,69.9999988079071],[100,37.9999995231628,0,63.9999985694885],[49.0000009536743,0.99999904632568,0,0],[30.0000011920929,0,5.0000011920929,0],[68.9999997615814,6.99999928474426,0,0],[58.9999973773956,0,6.00000023841858,0],[85.0000023841858,18.9999997615814,0,0],[89.9999976158142,11.0000014305115,0,0],[100,43.9999997615814,0,0],[100,34.0000033378601,0,1.99999809265137],[100,44.9999988079071,0,18.0000007152557],[100,30.0000011920929,0,19.9999988079071],[100,25,0,50],[100,17.0000016689301,0,50.9999990463257],[100,11.0000014305115,0,74.0000009536743],[100,0,5.0000011920929,72.0000028610229],[30.0000011920929,0,7.99999833106995,0],[50.9999990463257,0,9.00000333786011,0],[75,0,6.99999928474426,0],[100,15.9999966621399,0,26.9999980926514],[100,5.0000011920929,0,47.0000028610229],[100,0,9.00000333786011,72.0000028610229],[43.0000007152557,0,10.0000023841858,0],[43.0000007152557,0,12.0000004768372,0],[62.9999995231628,0,12.0000004768372,0],[62.9999995231628,0,18.0000007152557,0],[95.9999978542328,0,11.0000014305115,0],[82.9999983310699,0,20.9999978542328,0],[100,0,7.99999833106995,12.9999995231628],[100,0,15.9999966621399,9.00000333786011],[100,0,9.00000333786011,30.0000011920929],[100,0,18.9999997615814,23.0000019073486],[100,0,12.0000004768372,43.0000007152557],[100,0,24.0000009536743,37.9999995231628],[100,0,26.9999980926514,68.0000007152557],[100,0,27.9999971389771,64.9999976158142],[18.0000007152557,0,7.99999833106995,0],[37.9999995231628,0,14.9999976158142,0],[51.9999980926514,0,18.9999997615814,0],[100,0,31.0000002384186,6.99999928474426],[100,0,31.0000002384186,23.0000019073486],[100,0,33.0000042915344,35.0000023841858],[100,0,37.9999995231628,47.0000028610229],[27.9999971389771,0,12.0000004768372,0],[37.0000004768372,0,18.0000007152557,0],[34.0000033378601,0,18.9999997615814,0],[43.0000007152557,0,24.0000009536743,0],[56.0000002384186,0,25.9999990463257,0],[47.0000028610229,0,24.0000009536743,0],[49.0000009536743,0,27.9999971389771,0],[58.9999973773956,0,33.0000042915344,0],[87.0000004768372,0,37.9999995231628,0],[70.9999978542328,0,33.0000042915344,0],[68.9999997615814,0,37.0000004768372,0],[89.9999976158142,0,49.0000009536743,0],[100,0,43.9999997615814,17.0000016689301],[100,0,43.9999997615814,0],[94.9999988079071,0,47.0000028610229,0],[100,0,55.0000011920929,5.0000011920929],[100,0,44.9999988079071,31.9999992847443],[100,0,46.0000038146973,14.9999976158142],[100,0,50,6.99999928474426],[100,0,54.0000021457672,19.9999988079071],[100,0,46.0000038146973,46.0000038146973],[100,0,49.0000009536743,46.0000038146973],[100,0,52.9999971389771,20.9999978542328],[100,0,56.9999992847443,41.9999957084656],[100,0,48.0000019073486,60.0000023841858],[100,0,54.0000021457672,68.9999997615814],[100,0,61.0000014305115,61.0000014305115],[100,0,60.0000023841858,72.0000028610229],[24.0000009536743,0,15.9999966621399,0],[30.0000011920929,0,19.9999988079071,0],[43.0000007152557,0,26.9999980926514,0],[100,0,60.0000023841858,2.99999713897705],[100,0,64.9999976158142,30.0000011920929],[100,0,67.0000016689301,47.0000028610229],[31.0000002384186,0,19.9999988079071,0],[35.0000023841858,0,25,0],[47.0000028610229,0,31.9999992847443,0],[44.9999988079071,0,33.0000042915344,0],[83.9999973773956,0,56.0000002384186,0],[61.0000014305115,0,44.9999988079071,0],[100,0,66.0000026226044,9.00000333786011],[85.0000023841858,0,64.9999976158142,0],[100,0,67.0000016689301,28.9999961853027],[100,0,76.9999980926514,22.0000028610229],[100,0,70.9999978542328,43.0000007152557],[100,0,77.9999971389771,41.9999957084656],[98.0000019073486,0,72.0000028610229,61.0000014305115],[100,0,81.0000002384186,66.0000026226044],[26.9999980926514,0,23.0000019073486,0],[37.9999995231628,0,31.9999992847443,0],[55.0000011920929,0,47.0000028610229,0],[100,0,86.0000014305115,2.99999713897705],[100,0,85.0000023841858,24.0000009536743],[100,0,91.0000026226044,41.9999957084656],[79.0000021457672,0,100,75],[17.0000016689301,0,15.9999966621399,0],[26.9999980926514,0,25,0],[37.9999995231628,0,36.0000014305115,0],[80.0000011920929,0,89.9999976158142,0],[93.9999997615814,0,100,0],[94.9999988079071,0,100,26.9999980926514],[80.0000011920929,0,100,56.0000002384186],[26.9999980926514,0,37.9999995231628,0],[36.0000014305115,0,49.0000009536743,0],[57.9999983310699,0,80.0000011920929,0],[68.9999997615814,0,100,0],[69.9999988079071,0,100,9.00000333786011],[68.0000007152557,0,100,24.0000009536743],[64.9999976158142,0,100,41.9999957084656],[12.0000004768372,0,28.9999961853027,0],[19.9999988079071,0,43.9999997615814,0],[31.9999992847443,0,58.9999973773956,0],[56.9999992847443,0,100,0],[58.9999973773956,0,100,6.99999928474426],[56.0000002384186,0,100,26.9999980926514],[43.0000007152557,0,100,56.0000002384186],[10.0000023841858,0,33.0000042915344,0],[15.9999966621399,0,46.0000038146973,0],[24.0000009536743,0,56.9999992847443,0],[40.9999966621399,0,77.9999971389771,0],[50,0,100,0],[44.9999988079071,0,100,24.0000009536743],[34.0000033378601,0,100,60.0000023841858],[9.00000333786011,0,57.9999983310699,0],[12.9999995231628,0,72.0000028610229,0],[19.9999988079071,0,91.0000026226044,0],[28.9999961853027,0,100,0],[19.9999988079071,0,100,18.9999997615814],[18.0000007152557,0,100,31.0000002384186],[2.99999713897705,0,100,57.9999983310699],[6.00000023841858,0,56.0000002384186,0],[10.0000023841858,0,74.0000009536743,0],[13.9999985694885,0,79.0000021457672,0],[19.9999988079071,0,85.0000023841858,0],[22.0000028610229,0,100,7.99999833106995],[12.9999995231628,0,100,33.0000042915344],[6.99999928474426,0,100,49.0000009536743],[2.99999713897705,0,55.0000011920929,0],[0.99999904632568,0,68.0000007152557,0],[6.00000023841858,0,75.9999990463257,0],[2.99999713897705,0,85.0000023841858,0],[7.99999833106995,0,85.0000023841858,0],[6.00000023841858,0,100,0],[11.0000014305115,0,93.9999997615814,0],[7.99999833106995,0,100,0],[10.0000023841858,0,100,11.0000014305115],[0,0,100,28.9999961853027],[6.99999928474426,0,100,27.9999971389771],[0,2.99999713897705,100,40.9999966621399],[0,0,100,43.0000007152557],[0,2.99999713897705,100,63.9999985694885],[0,2.99999713897705,6.00000023841858,15.9999966621399],[0,5.0000011920929,11.0000014305115,23.0000019073486],[0,6.00000023841858,13.9999985694885,31.0000002384186],[0,6.99999928474426,17.0000016689301,43.0000007152557],[0,7.99999833106995,22.0000028610229,56.0000002384186],[0,10.0000023841858,33.0000042915344,72.0000028610229],[0,5.0000011920929,6.00000023841858,15.9999966621399],[0,7.99999833106995,9.00000333786011,25.9999990463257],[0,10.0000023841858,11.0000014305115,34.0000033378601],[0,12.9999995231628,14.9999976158142,44.9999988079071],[0,18.0000007152557,20.9999978542328,56.0000002384186],[0,26.9999980926514,36.0000014305115,72.0000028610229],[0,30.0000011920929,66.0000026226044,98.0000019073486],[0,0,9.00000333786011,19.9999988079071],[0,0,10.0000023841858,30.0000011920929],[0,0,12.0000004768372,40.9999966621399],[0,0,15.9999966621399,50],[0.99999904632568,0,25,64.9999976158142],[2.99999713897705,0,31.0000002384186,75],[28.9999961853027,0,36.0000014305115,100],[0,0,0,14.9999976158142],[0,0,0,25.9999990463257],[0,0,0,33.0000042915344],[0,0,0,43.9999997615814],[0,0,0,61.0000014305115],[0,0,0,76.9999980926514],[0,0,0,99.0000009536743],[0,0,0,11.0000014305115],[1.99999809265137,0,0,18.0000007152557],[2.99999713897705,0,0,31.9999992847443],[5.0000011920929,0,0,44.9999988079071],[11.0000014305115,0.99999904632568,0,63.9999985694885],[23.0000019073486,1.99999809265137,0,76.9999980926514],[33.0000042915344,2.99999713897705,0,94.9999988079071],[6.99999928474426,9.00000333786011,10.0000023841858,0],[12.9999995231628,14.9999976158142,14.9999976158142,0],[24.0000009536743,25,25.9999990463257,0],[46.0000038146973,44.9999988079071,49.0000009536743,0],[75,68.0000007152557,100,10.0000023841858],[80.0000011920929,73.0000019073486,100,19.9999988079071],[81.9999992847443,75.9999990463257,100,30.0000011920929],[6.00000023841858,0,6.99999928474426,9.00000333786011],[7.99999833106995,0,9.00000333786011,18.9999997615814],[12.0000004768372,0,12.0000004768372,30.0000011920929],[14.9999976158142,0,14.9999976158142,41.9999957084656],[19.9999988079071,0,19.9999988079071,64.9999976158142],[20.9999978542328,0,23.0000019073486,75],[15.9999966621399,0,31.0000002384186,81.9999992847443],[64.9999976158142,57.9999983310699,100,35.0000023841858],[0,25.9999990463257,100,68.9999997615814],[64.9999976158142,55.0000011920929,100,27.9999971389771],[0,19.9999988079071,94.9999988079071,46.0000038146973],[60.0000023841858,50,100,22.0000028610229],[0,14.9999976158142,77.9999971389771,36.0000014305115],[33.0000042915344,27.9999971389771,57.9999983310699,0],[0,9.00000333786011,50,24.0000009536743],[24.0000009536743,18.0000007152557,41.9999957084656,0],[0,6.99999928474426,38.9999985694885,17.0000016689301],[13.9999985694885,10.0000023841858,26.9999980926514,0],[0,4.00000214576721,30.0000011920929,11.0000014305115],[9.00000333786011,6.00000023841858,17.0000016689301,0],[0,2.99999713897705,18.9999997615814,6.00000023841858],[0,17.0000016689301,100,64.9999976158142],[0,14.9999976158142,100,43.0000007152557],[0,14.9999976158142,100,27.9999971389771],[10.0000023841858,10.0000023841858,73.0000019073486,0],[6.00000023841858,6.99999928474426,55.0000011920929,0],[4.00000214576721,5.0000011920929,43.9999997615814,0],[2.99999713897705,2.99999713897705,35.0000023841858,0],[50,57.9999983310699,100,44.9999988079071],[0,60.0000023841858,100,79.0000021457672],[30.0000011920929,56.0000002384186,100,37.0000004768372],[0,48.0000019073486,95.9999978542328,43.9999997615814],[10.0000023841858,49.0000009536743,100,35.0000023841858],[0,37.0000004768372,68.0000007152557,27.9999971389771],[19.9999988079071,31.9999992847443,57.9999983310699,0],[0,25.9999990463257,44.9999988079071,18.0000007152557],[12.0000004768372,22.0000028610229,43.0000007152557,0],[0,18.0000007152557,31.9999992847443,10.0000023841858],[9.00000333786011,14.9999976158142,34.0000033378601,0],[0,11.0000014305115,20.9999978542328,6.00000023841858],[6.00000023841858,9.00000333786011,23.0000019073486,0],[0,6.99999928474426,13.9999985694885,4.00000214576721],[0,51.9999980926514,100,62.0000004768372],[0,81.0000002384186,100,76.9999980926514],[0,57.9999983310699,100,33.0000042915344],[0,62.0000004768372,70.9999978542328,49.0000009536743],[0,58.9999973773956,100,18.0000007152557],[0,41.9999957084656,44.9999988079071,34.0000033378601],[0,34.0000033378601,51.9999980926514,0],[0,31.9999992847443,35.0000023841858,25],[0,23.0000019073486,36.0000014305115,0],[0,22.0000028610229,23.0000019073486,14.9999976158142],[0,14.9999976158142,25.9999990463257,0],[0,17.0000016689301,18.0000007152557,10.0000023841858],[0,11.0000014305115,19.9999988079071,0],[0,10.0000023841858,12.0000004768372,6.00000023841858],[56.9999992847443,80.0000011920929,100,44.9999988079071],[50,85.0000023841858,100,35.0000023841858],[39.9999976158142,86.0000014305115,100,30.0000011920929],[30.0000011920929,48.0000019073486,56.9999992847443,0],[14.9999976158142,28.9999961853027,33.0000042915344,0],[9.00000333786011,18.9999997615814,23.0000019073486,0],[5.0000011920929,11.0000014305115,14.9999976158142,0],[0,91.0000026226044,100,60.0000023841858],[0,94.9999988079071,100,28.9999961853027],[0,94.9999988079071,100,0],[0,47.0000028610229,40.9999966621399,0],[0,35.0000023841858,27.9999971389771,0],[0,25.9999990463257,18.9999997615814,0],[0,14.9999976158142,11.0000014305115,0],[0,74.0000009536743,100,72.0000028610229],[0,79.0000021457672,100,51.9999980926514],[0,69.9999988079071,66.0000026226044,30.0000011920929],[0,46.0000038146973,23.0000019073486,5.0000011920929],[0,33.0000042915344,12.9999995231628,0],[0,24.0000009536743,11.0000014305115,0],[0,15.9999966621399,9.00000333786011,0],[0,69.9999988079071,100,77.9999971389771],[0,73.0000019073486,100,80.0000011920929],[0,63.9999985694885,100,60.0000023841858],[0,58.9999973773956,48.0000019073486,48.0000019073486],[0,57.9999983310699,100,49.0000009536743],[0,48.0000019073486,37.9999995231628,34.0000033378601],[0,37.9999995231628,20.9999978542328,11.0000014305115],[0,37.9999995231628,26.9999980926514,23.0000019073486],[0,26.9999980926514,12.9999995231628,2.99999713897705],[0,25,14.9999976158142,11.0000014305115],[0,18.0000007152557,10.0000023841858,0.99999904632568],[0,18.0000007152557,12.0000004768372,6.99999928474426],[0,11.0000014305115,7.99999833106995,0],[0,10.0000023841858,9.00000333786011,2.99999713897705],[64.9999976158142,100,100,35.0000023841858],[50,100,100,25],[44.9999988079071,100,100,14.9999976158142],[11.0000014305115,44.9999988079071,22.0000028610229,0],[4.00000214576721,34.0000033378601,11.0000014305115,0],[0,24.0000009536743,6.99999928474426,0],[0,17.0000016689301,6.00000023841858,0],[60.0000023841858,100,44.9999988079071,30.0000011920929],[75,100,69.9999988079071,14.9999976158142],[50,100,14.9999976158142,10.0000023841858],[64.9999976158142,86.0000014305115,49.0000009536743,0],[43.9999997615814,82.9999983310699,0,0],[47.0000028610229,63.9999985694885,27.9999971389771,0],[14.9999976158142,50,0,0],[30.0000011920929,43.9999997615814,12.9999995231628,0],[6.99999928474426,37.9999995231628,0,0],[17.0000016689301,28.9999961853027,7.99999833106995,0],[2.99999713897705,26.9999980926514,0,0],[7.99999833106995,17.0000016689301,5.0000011920929,0],[0,18.0000007152557,0,0],[5.0000011920929,10.0000023841858,2.99999713897705,0],[69.9999988079071,100,55.0000011920929,25],[80.0000011920929,100,85.0000023841858,25],[67.0000016689301,100,30.0000011920929,10.0000023841858],[72.0000028610229,89.9999976158142,75,14.9999976158142],[63.9999985694885,100,12.0000004768372,0],[50,57.9999983310699,50,0],[26.9999980926514,47.0000028610229,0,0],[27.9999971389771,35.0000023841858,24.0000009536743,0],[17.0000016689301,37.0000004768372,0,0],[17.0000016689301,25,14.9999976158142,0],[10.0000023841858,25.9999990463257,0,0],[10.0000023841858,14.9999976158142,10.0000023841858,0],[6.00000023841858,14.9999976158142,0,0],[6.00000023841858,7.99999833106995,6.99999928474426,0],[83.9999973773956,100,44.9999988079071,5.0000011920929],[100,80.0000011920929,0,55.0000011920929],[75.9999990463257,100,6.99999928474426,0],[76.9999980926514,69.9999988079071,0,39.9999976158142],[73.0000019073486,100,0,0],[60.0000023841858,47.0000028610229,0,30.0000011920929],[40.9999966621399,55.0000011920929,0,0],[31.0000002384186,26.9999980926514,0,19.9999988079071],[25.9999990463257,39.9999976158142,0,0],[19.9999988079071,14.9999976158142,0,10.0000023841858],[18.0000007152557,31.0000002384186,0,0],[13.9999985694885,10.0000023841858,0,6.00000023841858],[10.0000023841858,19.9999988079071,0,0],[6.00000023841858,6.00000023841858,0,5.0000011920929],[100,80.0000011920929,69.9999988079071,25],[100,82.9999983310699,46.0000038146973,12.9999995231628],[100,80.0000011920929,30.0000011920929,5.0000011920929],[41.9999957084656,26.9999980926514,6.99999928474426,0],[31.0000002384186,19.9999988079071,5.0000011920929,0],[22.0000028610229,12.0000004768372,2.99999713897705,0],[12.0000004768372,6.99999928474426,1.99999809265137,0],[100,49.0000009536743,0,69.9999988079071],[100,43.9999997615814,0,75.9999990463257],[100,55.0000011920929,0,55.0000011920929],[57.9999983310699,17.0000016689301,0,46.0000038146973],[100,56.9999992847443,0,37.9999995231628],[41.9999957084656,7.99999833106995,0,39.9999976158142],[62.0000004768372,22.0000028610229,0,2.99999713897705],[30.0000011920929,4.00000214576721,0,31.0000002384186],[40.9999966621399,11.0000014305115,0,0],[12.9999995231628,2.99999713897705,0,17.0000016689301],[30.0000011920929,6.00000023841858,0,0],[7.99999833106995,0.99999904632568,0,12.9999995231628],[22.0000028610229,2.99999713897705,0,0],[6.00000023841858,0,0,9.00000333786011],[94.9999988079071,9.00000333786011,0,82.9999983310699],[100,0,18.0000007152557,82.9999983310699],[100,0,33.0000042915344,93.9999997615814],[100,18.9999997615814,0,75],[81.9999992847443,0,27.9999971389771,51.9999980926514],[55.0000011920929,0,26.9999980926514,73.0000019073486],[100,24.0000009536743,0,63.9999985694885],[62.0000004768372,0,20.9999978542328,31.0000002384186],[35.0000023841858,0,15.9999966621399,54.0000021457672],[51.9999980926514,6.00000023841858,0,25],[43.0000007152557,0,13.9999985694885,20.9999978542328],[17.0000016689301,0,9.00000333786011,36.0000014305115],[37.9999995231628,4.00000214576721,0,18.9999997615814],[28.9999961853027,0,10.0000023841858,13.9999985694885],[10.0000023841858,0,6.00000023841858,26.9999980926514],[26.9999980926514,2.99999713897705,0,12.9999995231628],[18.0000007152557,0,6.99999928474426,5.0000011920929],[7.99999833106995,0,5.0000011920929,17.0000016689301],[14.9999976158142,0,0,9.00000333786011],[11.0000014305115,0,5.0000011920929,2.99999713897705],[6.00000023841858,0,4.00000214576721,11.0000014305115],[58.9999973773956,0,52.9999971389771,80.0000011920929],[66.0000026226044,0,56.9999992847443,81.9999992847443],[77.9999971389771,0,62.9999995231628,67.0000016689301],[58.9999973773956,0,50,51.9999980926514],[75,0,60.0000023841858,55.0000011920929],[43.0000007152557,0,34.0000033378601,37.9999995231628],[41.9999957084656,0,33.0000042915344,26.9999980926514],[30.0000011920929,0,24.0000009536743,25.9999990463257],[30.0000011920929,0,19.9999988079071,14.9999976158142],[19.9999988079071,0,15.9999966621399,17.0000016689301],[18.9999997615814,0,13.9999985694885,9.00000333786011],[12.0000004768372,0,11.0000014305115,10.0000023841858],[13.9999985694885,0,10.0000023841858,6.00000023841858],[6.99999928474426,0,7.99999833106995,6.99999928474426],[80.0000011920929,0,62.9999995231628,75],[64.9999976158142,0,56.0000002384186,93.9999997615814],[85.0000023841858,0,54.0000021457672,51.9999980926514],[49.0000009536743,0,43.9999997615814,63.9999985694885],[85.0000023841858,0,50,31.0000002384186],[27.9999971389771,0,28.9999961853027,48.0000019073486],[51.9999980926514,0,31.9999992847443,0.99999904632568],[12.9999995231628,0,18.0000007152557,33.0000042915344],[37.0000004768372,0,19.9999988079071,0],[6.99999928474426,0,11.0000014305115,23.0000019073486],[23.0000019073486,0,12.9999995231628,0],[6.00000023841858,0,9.00000333786011,15.9999966621399],[13.9999985694885,0,10.0000023841858,0],[5.0000011920929,0,6.99999928474426,10.0000023841858],[81.9999992847443,0,63.9999985694885,69.9999988079071],[87.9999995231628,0,56.9999992847443,36.0000014305115],[98.0000019073486,0,56.9999992847443,17.0000016689301],[48.0000019073486,0,28.9999961853027,0],[31.9999992847443,0,18.9999997615814,0],[23.0000019073486,0,13.9999985694885,0],[13.9999985694885,0,9.00000333786011,0],[34.0000033378601,0,81.0000002384186,70.9999978542328],[33.0000042915344,0,85.0000023841858,81.9999992847443],[31.9999992847443,0,100,79.0000021457672],[48.0000019073486,0,100,52.9999971389771],[25,0,81.0000002384186,67.0000016689301],[26.9999980926514,0,94.9999988079071,55.0000011920929],[49.0000009536743,0,100,38.9999985694885],[15.9999966621399,0,74.0000009536743,56.9999992847443],[14.9999976158142,0,68.0000007152557,38.9999985694885],[24.0000009536743,0,46.0000038146973,10.0000023841858],[9.00000333786011,0,43.0000007152557,37.9999995231628],[10.0000023841858,0,49.0000009536743,27.9999971389771],[19.9999988079071,0,39.9999976158142,6.00000023841858],[6.00000023841858,0,27.9999971389771,26.9999980926514],[6.99999928474426,0,31.0000002384186,12.9999995231628],[17.0000016689301,0,34.0000033378601,2.99999713897705],[4.00000214576721,0,20.9999978542328,18.0000007152557],[5.0000011920929,0,24.0000009536743,9.00000333786011],[12.0000004768372,0,25.9999990463257,1.99999809265137],[1.99999809265137,0,12.0000004768372,11.0000014305115],[1.99999809265137,0,13.9999985694885,2.99999713897705],[1.99999809265137,0,100,72.0000028610229],[0,0,91.0000026226044,79.0000021457672],[12.9999995231628,0,100,46.0000038146973],[0,1.99999809265137,87.0000004768372,58.9999973773956],[23.0000019073486,0,100,17.0000016689301],[0,1.99999809265137,67.0000016689301,39.9999976158142],[12.0000004768372,0,79.0000021457672,6.00000023841858],[0,0.99999904632568,47.0000028610229,30.0000011920929],[11.0000014305115,0,66.0000026226044,1.99999809265137],[0,0,31.0000002384186,18.0000007152557],[9.00000333786011,0,52.9999971389771,0],[0,0,25,12.9999995231628],[5.0000011920929,0,39.9999976158142,0],[0,0,25.9999990463257,11.0000014305115],[0,0,28.9999961853027,0],[0,0,39.9999976158142,0],[0,0,50,0],[0,0,68.9999997615814,0.99999904632568],[0,0,87.9999995231628,2.99999713897705],[0,1.99999809265137,100,6.99999928474426],[0,4.00000214576721,100,12.0000004768372],[0,0,18.0000007152557,0.99999904632568],[0,0,31.9999992847443,1.99999809265137],[0,0,46.0000038146973,4.00000214576721],[0,0,57.9999983310699,6.00000023841858],[0,0.99999904632568,92.0000016689301,11.0000014305115],[0,1.99999809265137,100,19.9999988079071],[0,4.00000214576721,100,30.0000011920929],[0,0,19.9999988079071,4.00000214576721],[0,0.99999904632568,26.9999980926514,6.00000023841858],[0,1.99999809265137,35.0000023841858,9.00000333786011],[0,1.99999809265137,48.0000019073486,17.0000016689301],[0,2.99999713897705,87.0000004768372,30.0000011920929],[0,4.00000214576721,100,43.0000007152557],[0,5.0000011920929,100,52.9999971389771],[12.9999995231628,0,10.0000023841858,1.99999809265137],[24.0000009536743,0,18.9999997615814,4.00000214576721],[31.9999992847443,0,24.0000009536743,10.0000023841858],[43.9999997615814,0,35.0000023841858,19.9999988079071],[56.0000002384186,0,43.9999997615814,33.0000042915344],[75.9999990463257,0,63.9999985694885,62.0000004768372],[89.9999976158142,0,75,82.9999983310699],[18.9999997615814,0,6.00000023841858,0],[34.0000033378601,0,9.00000333786011,0],[47.0000028610229,0,11.0000014305115,0],[67.0000016689301,0,12.0000004768372,1.99999809265137],[92.0000016689301,0,14.9999976158142,5.0000011920929],[100,0,10.0000023841858,25],[100,0,9.00000333786011,39.9999976158142],[31.9999992847443,0,7.99999833106995,0],[44.9999988079071,0,9.00000333786011,0],[55.0000011920929,0,9.00000333786011,0],[82.9999983310699,0,10.0000023841858,0],[100,0,5.0000011920929,5.0000011920929],[100,0,0,22.0000028610229],[100,4.00000214576721,0,30.0000011920929],[15.9999966621399,4.00000214576721,0,1.99999809265137],[25,6.99999928474426,0,4.00000214576721],[41.9999957084656,14.9999976158142,0,6.00000023841858],[55.0000011920929,24.0000009536743,0,9.00000333786011],[64.9999976158142,30.0000011920929,0,11.0000014305115],[100,56.0000002384186,0,23.0000019073486],[100,62.0000004768372,0,51.9999980926514],[10.0000023841858,4.00000214576721,0,0.99999904632568],[24.0000009536743,9.00000333786011,0,1.99999809265137],[37.9999995231628,18.0000007152557,0,6.00000023841858],[50,25,0,10.0000023841858],[100,62.0000004768372,0,19.9999988079071],[100,67.0000016689301,0,37.9999995231628],[100,68.0000007152557,0,51.9999980926514],[13.9999985694885,2.99999713897705,0,0],[24.0000009536743,6.99999928474426,0,0],[30.0000011920929,14.9999976158142,0,0],[55.0000011920929,30.0000011920929,0,0],[89.9999976158142,56.9999992847443,0,0],[100,68.9999997615814,0,9.00000333786011],[100,70.9999978542328,0,18.0000007152557],[6.99999928474426,6.00000023841858,0,0],[11.0000014305115,9.00000333786011,0,0],[19.9999988079071,17.0000016689301,0,1.99999809265137],[31.0000002384186,30.0000011920929,0,6.99999928474426],[51.9999980926514,49.0000009536743,0,13.9999985694885],[64.9999976158142,63.9999985694885,0,30.0000011920929],[75.9999990463257,77.9999971389771,0,47.0000028610229],[0,12.9999995231628,0,0],[0.99999904632568,19.9999988079071,0,0],[2.99999713897705,34.0000033378601,0,0],[6.00000023841858,49.0000009536743,0,0],[9.00000333786011,67.0000016689301,0,0],[17.0000016689301,100,0,2.99999713897705],[6.00000023841858,100,0,22.0000028610229],[1.99999809265137,12.9999995231628,0,0],[2.99999713897705,20.9999978542328,0,0],[5.0000011920929,26.9999980926514,0,0],[10.0000023841858,43.0000007152557,0,1.99999809265137],[20.9999978542328,61.0000014305115,0,4.00000214576721],[25,79.0000021457672,0,12.0000004768372],[11.0000014305115,100,0,43.0000007152557],[0,17.0000016689301,0,1.99999809265137],[0,25,0,2.99999713897705],[0,30.0000011920929,0,5.0000011920929],[1.99999809265137,43.9999997615814,0,12.0000004768372],[5.0000011920929,56.9999992847443,0,18.9999997615814],[6.99999928474426,76.9999980926514,0,34.0000033378601],[0,97.0000028610229,0,58.9999973773956],[0,14.9999976158142,7.99999833106995,0.99999904632568],[0,23.0000019073486,10.0000023841858,1.99999809265137],[0,30.0000011920929,12.0000004768372,6.00000023841858],[0,36.0000014305115,20.9999978542328,10.0000023841858],[0,50,27.9999971389771,19.9999988079071],[0,60.0000023841858,36.0000014305115,31.9999992847443],[0,68.0000007152557,47.0000028610229,41.9999957084656],[0,15.9999966621399,7.99999833106995,0],[0,24.0000009536743,10.0000023841858,0],[0,36.0000014305115,13.9999985694885,0],[0,44.9999988079071,19.9999988079071,0],[0,68.9999997615814,34.0000033378601,5.0000011920929],[0,82.9999983310699,54.0000021457672,15.9999966621399],[0,89.9999976158142,72.0000028610229,28.9999961853027],[0,9.00000333786011,6.00000023841858,0],[0,17.0000016689301,10.0000023841858,0],[0,30.0000011920929,13.9999985694885,0],[0,46.0000038146973,22.0000028610229,0],[0,66.0000026226044,37.9999995231628,0],[0,79.0000021457672,57.9999983310699,0],[0,100,80.0000011920929,1.99999809265137],[0,13.9999985694885,31.0000002384186,0],[0,18.9999997615814,40.9999966621399,0],[0,26.9999980926514,55.0000011920929,0],[0,36.0000014305115,70.9999978542328,0],[0,44.9999988079071,91.0000026226044,0],[0,52.9999971389771,100,1.99999809265137],[0,56.0000002384186,100,7.99999833106995],[0,10.0000023841858,25,0],[0,14.9999976158142,36.0000014305115,0.99999904632568],[0,24.0000009536743,51.9999980926514,2.99999713897705],[0,36.0000014305115,75.9999990463257,9.00000333786011],[0,43.0000007152557,97.0000028610229,17.0000016689301],[0,50.9999990463257,100,36.0000014305115],[0,52.9999971389771,100,48.0000019073486],[0,7.99999833106995,23.0000019073486,1.99999809265137],[0,14.9999976158142,34.0000033378601,5.0000011920929],[0,20.9999978542328,48.0000019073486,10.0000023841858],[0,31.0000002384186,62.0000004768372,18.0000007152557],[0,37.9999995231628,77.9999971389771,28.9999961853027],[0,51.9999980926514,100,54.0000021457672],[0,55.0000011920929,100,63.9999985694885],[0,4.00000214576721,18.0000007152557,0],[0,6.00000023841858,30.0000011920929,0],[0,10.0000023841858,50,0],[0,9.00000333786011,79.0000021457672,0],[0,10.0000023841858,99.0000009536743,0],[0,18.0000007152557,100,0],[0,22.0000028610229,85.0000023841858,11.0000014305115],[0,25,94.9999988079071,0],[0,30.0000011920929,94.9999988079071,0],[0,30.0000011920929,55.0000011920929,0],[0,35.0000023841858,68.9999997615814,0],[0,41.9999957084656,100,6.99999928474426],[0,52.9999971389771,100,4.00000214576721],[0,46.0000038146973,100,11.0000014305115],[0,18.0000007152557,14.9999976158142,0],[0,60.0000023841858,60.0000023841858,0],[0,75,75,0],[0,69.9999988079071,60.0000023841858,5.0000011920929],[0,60.0000023841858,44.9999988079071,18.0000007152557],[0,80.0000011920929,41.9999957084656,19.9999988079071],[0,100,30.0000011920929,61.0000014305115],[0,9.00000333786011,5.0000011920929,0],[0,55.0000011920929,23.0000019073486,0],[0,75,30.0000011920929,0],[0,89.9999976158142,30.0000011920929,6.99999928474426],[0,100,44.9999988079071,18.0000007152557],[0,100,64.9999976158142,27.9999971389771],[0,80.0000011920929,44.9999988079071,55.0000011920929],[0,18.0000007152557,2.99999713897705,0],[1.99999809265137,31.0000002384186,0,0],[0,37.9999995231628,1.99999809265137,5.0000011920929],[0,55.0000011920929,2.99999713897705,10.0000023841858],[0,75,14.9999976158142,14.9999976158142],[0,80.0000011920929,14.9999976158142,19.9999988079071],[0,100,10.0000023841858,35.0000023841858],[2.99999713897705,7.99999833106995,0,0],[6.00000023841858,19.9999988079071,0,0],[14.9999976158142,35.0000023841858,0,0],[19.9999988079071,35.0000023841858,0,0],[30.0000011920929,39.9999976158142,0,0],[36.0000014305115,50,0,0],[50,69.9999988079071,0,0],[6.00000023841858,5.0000011920929,0,0],[19.9999988079071,17.0000016689301,0,0],[30.0000011920929,19.9999988079071,0,2.99999713897705],[43.0000007152557,37.9999995231628,0,0],[60.0000023841858,57.9999983310699,0,18.9999997615814],[31.9999992847443,41.9999957084656,0,55.0000011920929],[72.0000028610229,100,76.9999980926514,39.9999976158142],[19.9999988079071,10.0000023841858,0,0],[39.9999976158142,20.9999978542328,0,0],[50,31.9999992847443,0,0],[50,25.9999990463257,0,0],[50,24.0000009536743,0,10.0000023841858],[80.0000011920929,52.9999971389771,0,0],[55.0000011920929,35.0000023841858,0,6.99999928474426],[12.0000004768372,0,1.99999809265137,0],[39.9999976158142,0,5.0000011920929,6.00000023841858],[56.9999992847443,0,6.00000023841858,12.9999995231628],[100,0,0,5.0000011920929],[77.9999971389771,27.9999971389771,0,0],[100,50,0,10.0000023841858],[100,43.0000007152557,0,64.9999976158142],[25,0,10.0000023841858,0],[50,0,25,0],[69.9999988079071,0,23.0000019073486,0],[94.9999988079071,0,25,0],[100,10.0000023841858,0,27.9999971389771],[100,19.9999988079071,0,39.9999976158142],[80.0000011920929,14.9999976158142,0,44.9999988079071],[27.9999971389771,0,13.9999985694885,0],[51.9999980926514,0,25,0],[69.9999988079071,0,37.9999995231628,7.99999833106995],[89.9999976158142,0,27.9999971389771,22.0000028610229],[50,0,25,30.0000011920929],[100,0,43.0000007152557,60.0000023841858],[80.0000011920929,0,10.0000023841858,68.0000007152557],[18.0000007152557,0,13.9999985694885,0],[55.0000011920929,0,50,0],[60.0000023841858,0,50,0],[60.0000023841858,0,55.0000011920929,0],[80.0000011920929,0,75,0],[85.0000023841858,0,100,55.0000011920929],[100,0,85.0000023841858,50],[6.00000023841858,0,10.0000023841858,0],[19.9999988079071,0,30.0000011920929,0],[30.0000011920929,0,44.9999988079071,0],[43.0000007152557,0,60.0000023841858,0],[60.0000023841858,0,80.0000011920929,6.99999928474426],[44.9999988079071,0,80.0000011920929,35.0000023841858],[31.9999992847443,0,100,39.9999976158142],[12.0000004768372,0,50,6.99999928474426],[13.9999985694885,0,36.0000014305115,10.0000023841858],[25,0,39.9999976158142,14.9999976158142],[25,0,80.0000011920929,30.0000011920929],[39.9999976158142,0,100,37.9999995231628],[39.9999976158142,30.0000011920929,69.9999988079071,25],[25,0,100,80.0000011920929],[0,1.99999809265137,14.9999976158142,0],[0,1.99999809265137,14.9999976158142,2.99999713897705],[0,4.00000214576721,19.9999988079071,6.00000023841858],[0,7.99999833106995,35.0000023841858,10.0000023841858],[0,12.0000004768372,35.0000023841858,25],[0,25,44.9999988079071,39.9999976158142],[0,30.0000011920929,69.9999988079071,55.0000011920929],[0,5.0000011920929,14.9999976158142,0],[0,10.0000023841858,30.0000011920929,0],[0,14.9999976158142,39.9999976158142,4.00000214576721],[0,19.9999988079071,50,5.0000011920929],[0,30.0000011920929,72.0000028610229,11.0000014305115],[0,44.9999988079071,100,25],[0,46.0000038146973,100,33.0000042915344],[0,18.0000007152557,27.9999971389771,2.99999713897705],[0,24.0000009536743,37.9999995231628,5.0000011920929],[0,35.0000023841858,50,12.0000004768372],[0,51.9999980926514,100,35.0000023841858],[0,60.0000023841858,100,43.9999997615814],[0,39.9999976158142,55.0000011920929,60.0000023841858],[50,60.0000023841858,100,48.0000019073486],[0,15.9999966621399,18.9999997615814,0],[0,25,19.9999988079071,10.0000023841858],[0,39.9999976158142,30.0000011920929,15.9999966621399],[0,39.9999976158142,35.0000023841858,19.9999988079071],[0,55.0000011920929,60.0000023841858,26.9999980926514],[0,44.9999988079071,50,30.0000011920929],[0,64.9999976158142,100,35.0000023841858],[0,1.99999809265137,6.00000023841858,6.99999928474426],[0,2.99999713897705,10.0000023841858,10.0000023841858],[0,4.00000214576721,12.0000004768372,17.0000016689301],[0,7.99999833106995,20.9999978542328,31.9999992847443],[0,10.0000023841858,26.9999980926514,50],[0,17.0000016689301,50,64.9999976158142],[0,22.0000028610229,85.0000023841858,85.0000023841858],[0,1.99999809265137,7.99999833106995,10.0000023841858],[0,2.99999713897705,14.9999976158142,19.9999988079071],[0,4.00000214576721,22.0000028610229,31.9999992847443],[2.99999713897705,0,10.0000023841858,19.9999988079071],[9.00000333786011,0,12.9999995231628,30.0000011920929],[1.99999809265137,0,9.00000333786011,36.0000014305115],[0,0,0,72.0000028610229],[1.99999809265137,0,0,5.0000011920929],[10.0000023841858,0,2.99999713897705,15.9999966621399],[6.99999928474426,0,0,30.0000011920929],[10.0000023841858,0.99999904632568,0,39.9999976158142],[23.0000019073486,1.99999809265137,0,62.9999995231628],[33.0000042915344,4.00000214576721,0,72.0000028610229],[35.0000023841858,4.00000214576721,0,93.9999997615814],[30.0000011920929,25,39.9999976158142,19.9999988079071],[89.9999976158142,5.0000011920929,5.0000011920929,0],[35.0000023841858,0,60.0000023841858,0],[0,19.9999988079071,30.0000011920929,25],[0,0,69.9999988079071,0],[0,19.9999988079071,35.0000023841858,0],[0,39.9999976158142,25,0],[0,50,0,0],[5.0000011920929,35.0000023841858,14.9999976158142,25],[14.9999976158142,75,0,0],[80.0000011920929,0,39.9999976158142,0],[10.0000023841858,0,100,0],[0,10.0000023841858,35.0000023841858,0],[10.0000023841858,14.9999976158142,5.0000011920929,19.9999988079071],[0,25,25,0],[0,50,14.9999976158142,0],[0,69.9999988079071,0,0],[55.0000011920929,60.0000023841858,0,0],[25,0,0,25],[35.0000023841858,0,19.9999988079071,25],[19.9999988079071,0,30.0000011920929,25],[19.9999988079071,25,60.0000023841858,25],[19.9999988079071,30.0000011920929,69.9999988079071,14.9999976158142],[30.0000011920929,30.0000011920929,60.0000023841858,10.0000023841858],[0,19.9999988079071,50,30.0000011920929],[30.0000011920929,39.9999976158142,69.9999988079071,0],[30.0000011920929,50,85.0000023841858,0],[0,0,0,39.9999976158142],[0,2.99999713897705,55.0000011920929,87.0000004768372],[60.0000023841858,0,60.0000023841858,91.0000026226044],[0,22.0000028610229,100,88.9999985694885],[0,39.9999976158142,22.0000028610229,87.0000004768372],[100,35.0000023841858,0,100],[0,0,14.9999976158142,81.9999992847443],[0,12.9999995231628,49.0000009536743,98.0000019073486],[0,12.9999995231628,49.0000009536743,98.0000019073486],[100,87.9999995231628,0,5.0000011920929],[100,87.9999995231628,0,5.0000011920929],[0,0,0,6.00000023841858],[0,1.99999809265137,0,60.0000023841858],[0,1.99999809265137,0,68.0000007152557],[0,0,0,10.0000023841858],[0,0,0,17.0000016689301],[0,0,0,24.0000009536743],[0,0,0,28.9999961853027],[0,0,0,31.0000002384186],[0,0,0,37.0000004768372],[0,0.99999904632568,0,43.0000007152557],[0,0.99999904632568,0,50.9999990463257],[100,0,58.9999973773956,0],[100,0,58.9999973773956,0],[0.99999904632568,0.99999904632568,0.99999904632568,100],[98.0000019073486,0,0,0],[93.0000007152557,0,100,0],[0,97.0000028610229,0,0],[0,51.9999980926514,100,0],[0,0.99999904632568,98.0000019073486,0],[0,52.9999971389771,100,0],[0,52.9999971389771,100,0],[0,0,0,100],[100,10.0000023841858,0,10.0000023841858],[100,10.0000023841858,0,10.0000023841858],[100,0,0,0],[0,100,0,0],[0,0,100,0],[37.9999995231628,87.9999995231628,0,0],[37.9999995231628,87.9999995231628,0,0],[0,89.9999976158142,86.0000014305115,0],[0,89.9999976158142,86.0000014305115,0],[100,73.0000019073486,0,1.99999809265137],[100,73.0000019073486,0,1.99999809265137],[2.99999713897705,88.9999985694885,0,0],[2.99999713897705,88.9999985694885,0,0],[0,100,14.9999976158142,4.00000214576721],[0,100,14.9999976158142,4.00000214576721],[98.0000019073486,100,0,0],[98.0000019073486,100,0,0],[0,1.99999809265137,2.99999713897705,6.00000023841858],[0,13.9999985694885,27.9999971389771,55.0000011920929],[0,17.0000016689301,34.0000033378601,62.0000004768372],[0,1.99999809265137,5.0000011920929,9.00000333786011],[0,4.00000214576721,7.99999833106995,17.0000016689301],[0,4.00000214576721,9.00000333786011,24.0000009536743],[0,5.0000011920929,10.0000023841858,28.9999961853027],[0,6.00000023841858,12.0000004768372,31.0000002384186],[0,7.99999833106995,13.9999985694885,37.9999995231628],[0,9.00000333786011,15.9999966621399,43.0000007152557],[0,11.0000014305115,19.9999988079071,47.0000028610229],[0,75,89.9999976158142,0],[0,75,89.9999976158142,0],[0,4.00000214576721,100,0],[0,0.99999904632568,100,0],[0,0.99999904632568,100,0]];
}

//if anything is selected:
if(activeDocument.selection.length >0){
	//and it's the right kind of object:
	if(activeDocument.selection[0].fillColor.typename == "CMYKColor"){
		fil = activeDocument.selection[0].fillColor
		inpt = fil.cyan+","+fil.magenta+","+fil.yellow+","+fil.black;
	}else if(activeDocument.selection[0].fillColor.typename == "RGBColor"){
		fil = activeDocument.selection[0].fillColor
		inpt = fil.red+","+fil.green+","+fil.blue;
	}else{
		//otherwise, prompt user for input:
		msg = ("Selected Object's color space:"+activeDocument.selection[0].fillColor.typename+" is not RGB or CMYK");
		inpt = getManual(msg);
	}
	//if no input quit, otherwise proceed.
	if(inpt.length >1){
	getCols();
	}
}else{ 
	// if no object was selected prompt user for input:
	inpt = getManual();
	getCols();
}
//----------------------------------
//----------Functions---------------
//----------------------------------
function getManual(msg){
if(msg == undefined){msg = "No Object detected";}
	//gets manual color from user if nothing is selected. (or if group is selected)
	return prompt(msg+":\nPress Enter to exit, or \n\nEnter comma separated "+space+" values here:","");
}
//----------------------------getCols--------------------
function getCols(prec){
		//
	//walk through Pantone array to look for any color matches
	
	if (prec== undefined)
	{
		//set default precision for color matching
		prec = 1;
	}
	num = inpt.split(",");
	colen = cols.length;
	len = names.length;
	loc = 0; 
	oneFound = false;
	matchlist = [];
	for (j=0;j<colen;j++)
	{
	 isbest = compare(num,cols[j],cols[loc],prec);
		if (isbest == true)
		{
			oneFound = true;
			matchlist.push(names[j]);//+" ("+cols[j]+")");
			loc = j;
			
		}
	}
	if(oneFound == true){
		if (space == "CMYK")
		{
		myCol = "C:"+Math.round(num[0])+","+"M:"+Math.round(num[1])+","+"Y:"+Math.round(num[2])+","+"K:"+Math.round(num[3]);
		}else{
		myCol = "R:"+Math.round(num[0])+","+"G:"+Math.round(num[1])+","+"B:"+Math.round(num[2]);
	
		}
		alert(myCol+ "\nmatches\n"+matchlist.join("\n")+"\nwith "+prec+" deg. of precision.");
	}else {
		 
		if(prec > maxprec){
			//nothing
			newmax = prompt ("No match found within "+maxprec+" deg.\nPress enter to quit, or enter a higher number to keep searching.","");
			if (newmax.length>0)
			{
			maxprec = newmax;
			prec++;
			getCols(prec);
			}
		} else{
			prec++;
			getCols(prec);
		}
	}
}
//----------------------------compare--------------------
function compare(arr1,arr2,arrBest,precs){
	t1 = 0;
	max = arr1.length;
	for (w=0;w<max;w++){
		d1= diff(arr1[w],arr2[w])
			
			if(d1>precs){
				return false;
				//if any comparison is ridiculously divergent, 
				//don't bother to check the others...	
			}

	}	
		return true;

}
//----------------------------diff--------------------
function diff(a,b){
	//returns difference between positive numbers
	if (a>b){
			return (a-b);
		}
	else {
		return (b-a);
	}
}